# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'jassdlg.ui'
#
# Created: Fri Nov 23 23:14:34 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_jassdlg(object):
    def setupUi(self, jassdlg):
        jassdlg.setObjectName(_fromUtf8("jassdlg"))
        jassdlg.resize(1069, 458)
        self.buttonBox = QtGui.QDialogButtonBox(jassdlg)
        self.buttonBox.setGeometry(QtCore.QRect(840, 420, 191, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.label = QtGui.QLabel(jassdlg)
        self.label.setGeometry(QtCore.QRect(40, 30, 141, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.edjob = QtGui.QLabel(jassdlg)
        self.edjob.setGeometry(QtCore.QRect(180, 30, 331, 17))
        self.edjob.setText(_fromUtf8(""))
        self.edjob.setObjectName(_fromUtf8("edjob"))
        self.label_2 = QtGui.QLabel(jassdlg)
        self.label_2.setGeometry(QtCore.QRect(50, 60, 66, 17))
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.label_3 = QtGui.QLabel(jassdlg)
        self.label_3.setGeometry(QtCore.QRect(170, 60, 41, 17))
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.label_4 = QtGui.QLabel(jassdlg)
        self.label_4.setGeometry(QtCore.QRect(340, 60, 81, 17))
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.label_5 = QtGui.QLabel(jassdlg)
        self.label_5.setGeometry(QtCore.QRect(640, 60, 71, 17))
        self.label_5.setObjectName(_fromUtf8("label_5"))
        self.label_6 = QtGui.QLabel(jassdlg)
        self.label_6.setGeometry(QtCore.QRect(900, 60, 51, 17))
        self.label_6.setObjectName(_fromUtf8("label_6"))
        self.widget = QtGui.QWidget(jassdlg)
        self.widget.setGeometry(QtCore.QRect(30, 90, 1001, 301))
        self.widget.setObjectName(_fromUtf8("widget"))
        self.gridLayout = QtGui.QGridLayout(self.widget)
        self.gridLayout.setMargin(0)
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.assvar0 = QtGui.QComboBox(self.widget)
        self.assvar0.setObjectName(_fromUtf8("assvar0"))
        self.assvar0.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assvar0, 0, 0, 1, 1)
        self.assop0 = QtGui.QComboBox(self.widget)
        self.assop0.setObjectName(_fromUtf8("assop0"))
        self.assop0.addItem(_fromUtf8(""))
        self.assop0.addItem(_fromUtf8(""))
        self.assop0.addItem(_fromUtf8(""))
        self.assop0.addItem(_fromUtf8(""))
        self.assop0.addItem(_fromUtf8(""))
        self.assop0.addItem(_fromUtf8(""))
        self.assop0.addItem(_fromUtf8(""))
        self.assop0.addItem(_fromUtf8(""))
        self.assop0.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assop0, 0, 1, 1, 1)
        self.FS0 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FS0.setFont(font)
        self.FS0.setObjectName(_fromUtf8("FS0"))
        self.gridLayout.addWidget(self.FS0, 0, 2, 1, 1)
        self.FN0 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FN0.setFont(font)
        self.FN0.setObjectName(_fromUtf8("FN0"))
        self.gridLayout.addWidget(self.FN0, 0, 3, 1, 1)
        self.FE0 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FE0.setFont(font)
        self.FE0.setObjectName(_fromUtf8("FE0"))
        self.gridLayout.addWidget(self.FE0, 0, 4, 1, 1)
        self.FA0 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FA0.setFont(font)
        self.FA0.setObjectName(_fromUtf8("FA0"))
        self.gridLayout.addWidget(self.FA0, 0, 5, 1, 1)
        self.FC0 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FC0.setFont(font)
        self.FC0.setObjectName(_fromUtf8("FC0"))
        self.gridLayout.addWidget(self.FC0, 0, 6, 1, 1)
        self.FR0 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FR0.setFont(font)
        self.FR0.setObjectName(_fromUtf8("FR0"))
        self.gridLayout.addWidget(self.FR0, 0, 7, 1, 1)
        self.textval0 = QtGui.QLineEdit(self.widget)
        self.textval0.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.textval0.setFont(font)
        self.textval0.setMaxLength(49)
        self.textval0.setObjectName(_fromUtf8("textval0"))
        self.gridLayout.addWidget(self.textval0, 0, 8, 1, 1)
        self.asstext0 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(11)
        self.asstext0.setFont(font)
        self.asstext0.setObjectName(_fromUtf8("asstext0"))
        self.gridLayout.addWidget(self.asstext0, 0, 9, 1, 1)
        self.intval0 = QtGui.QSpinBox(self.widget)
        self.intval0.setMinimum(-1000000)
        self.intval0.setMaximum(1000000)
        self.intval0.setProperty("value", 0)
        self.intval0.setObjectName(_fromUtf8("intval0"))
        self.gridLayout.addWidget(self.intval0, 0, 10, 1, 1)
        self.ac0 = QtGui.QCheckBox(self.widget)
        self.ac0.setObjectName(_fromUtf8("ac0"))
        self.gridLayout.addWidget(self.ac0, 0, 11, 1, 1)
        self.assvar1 = QtGui.QComboBox(self.widget)
        self.assvar1.setObjectName(_fromUtf8("assvar1"))
        self.assvar1.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assvar1, 1, 0, 1, 1)
        self.assop1 = QtGui.QComboBox(self.widget)
        self.assop1.setObjectName(_fromUtf8("assop1"))
        self.assop1.addItem(_fromUtf8(""))
        self.assop1.addItem(_fromUtf8(""))
        self.assop1.addItem(_fromUtf8(""))
        self.assop1.addItem(_fromUtf8(""))
        self.assop1.addItem(_fromUtf8(""))
        self.assop1.addItem(_fromUtf8(""))
        self.assop1.addItem(_fromUtf8(""))
        self.assop1.addItem(_fromUtf8(""))
        self.assop1.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assop1, 1, 1, 1, 1)
        self.FS1 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FS1.setFont(font)
        self.FS1.setObjectName(_fromUtf8("FS1"))
        self.gridLayout.addWidget(self.FS1, 1, 2, 1, 1)
        self.FN1 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FN1.setFont(font)
        self.FN1.setObjectName(_fromUtf8("FN1"))
        self.gridLayout.addWidget(self.FN1, 1, 3, 1, 1)
        self.FE1 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FE1.setFont(font)
        self.FE1.setObjectName(_fromUtf8("FE1"))
        self.gridLayout.addWidget(self.FE1, 1, 4, 1, 1)
        self.FA1 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FA1.setFont(font)
        self.FA1.setObjectName(_fromUtf8("FA1"))
        self.gridLayout.addWidget(self.FA1, 1, 5, 1, 1)
        self.FC1 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FC1.setFont(font)
        self.FC1.setObjectName(_fromUtf8("FC1"))
        self.gridLayout.addWidget(self.FC1, 1, 6, 1, 1)
        self.FR1 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FR1.setFont(font)
        self.FR1.setObjectName(_fromUtf8("FR1"))
        self.gridLayout.addWidget(self.FR1, 1, 7, 1, 1)
        self.textval1 = QtGui.QLineEdit(self.widget)
        self.textval1.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.textval1.setFont(font)
        self.textval1.setMaxLength(49)
        self.textval1.setObjectName(_fromUtf8("textval1"))
        self.gridLayout.addWidget(self.textval1, 1, 8, 1, 1)
        self.asstext1 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(11)
        self.asstext1.setFont(font)
        self.asstext1.setObjectName(_fromUtf8("asstext1"))
        self.gridLayout.addWidget(self.asstext1, 1, 9, 1, 1)
        self.intval1 = QtGui.QSpinBox(self.widget)
        self.intval1.setMinimum(-1000000)
        self.intval1.setMaximum(1000000)
        self.intval1.setProperty("value", 0)
        self.intval1.setObjectName(_fromUtf8("intval1"))
        self.gridLayout.addWidget(self.intval1, 1, 10, 1, 1)
        self.ac1 = QtGui.QCheckBox(self.widget)
        self.ac1.setObjectName(_fromUtf8("ac1"))
        self.gridLayout.addWidget(self.ac1, 1, 11, 1, 1)
        self.assvar2 = QtGui.QComboBox(self.widget)
        self.assvar2.setObjectName(_fromUtf8("assvar2"))
        self.assvar2.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assvar2, 2, 0, 1, 1)
        self.assop2 = QtGui.QComboBox(self.widget)
        self.assop2.setObjectName(_fromUtf8("assop2"))
        self.assop2.addItem(_fromUtf8(""))
        self.assop2.addItem(_fromUtf8(""))
        self.assop2.addItem(_fromUtf8(""))
        self.assop2.addItem(_fromUtf8(""))
        self.assop2.addItem(_fromUtf8(""))
        self.assop2.addItem(_fromUtf8(""))
        self.assop2.addItem(_fromUtf8(""))
        self.assop2.addItem(_fromUtf8(""))
        self.assop2.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assop2, 2, 1, 1, 1)
        self.FS2 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FS2.setFont(font)
        self.FS2.setObjectName(_fromUtf8("FS2"))
        self.gridLayout.addWidget(self.FS2, 2, 2, 1, 1)
        self.FN2 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FN2.setFont(font)
        self.FN2.setObjectName(_fromUtf8("FN2"))
        self.gridLayout.addWidget(self.FN2, 2, 3, 1, 1)
        self.FE2 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FE2.setFont(font)
        self.FE2.setObjectName(_fromUtf8("FE2"))
        self.gridLayout.addWidget(self.FE2, 2, 4, 1, 1)
        self.FA2 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FA2.setFont(font)
        self.FA2.setObjectName(_fromUtf8("FA2"))
        self.gridLayout.addWidget(self.FA2, 2, 5, 1, 1)
        self.FC2 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FC2.setFont(font)
        self.FC2.setObjectName(_fromUtf8("FC2"))
        self.gridLayout.addWidget(self.FC2, 2, 6, 1, 1)
        self.FR2 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FR2.setFont(font)
        self.FR2.setObjectName(_fromUtf8("FR2"))
        self.gridLayout.addWidget(self.FR2, 2, 7, 1, 1)
        self.textval2 = QtGui.QLineEdit(self.widget)
        self.textval2.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.textval2.setFont(font)
        self.textval2.setMaxLength(49)
        self.textval2.setObjectName(_fromUtf8("textval2"))
        self.gridLayout.addWidget(self.textval2, 2, 8, 1, 1)
        self.asstext2 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(11)
        self.asstext2.setFont(font)
        self.asstext2.setObjectName(_fromUtf8("asstext2"))
        self.gridLayout.addWidget(self.asstext2, 2, 9, 1, 1)
        self.intval2 = QtGui.QSpinBox(self.widget)
        self.intval2.setMinimum(-1000000)
        self.intval2.setMaximum(1000000)
        self.intval2.setProperty("value", 0)
        self.intval2.setObjectName(_fromUtf8("intval2"))
        self.gridLayout.addWidget(self.intval2, 2, 10, 1, 1)
        self.ac2 = QtGui.QCheckBox(self.widget)
        self.ac2.setObjectName(_fromUtf8("ac2"))
        self.gridLayout.addWidget(self.ac2, 2, 11, 1, 1)
        self.assvar3 = QtGui.QComboBox(self.widget)
        self.assvar3.setObjectName(_fromUtf8("assvar3"))
        self.assvar3.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assvar3, 3, 0, 1, 1)
        self.assop3 = QtGui.QComboBox(self.widget)
        self.assop3.setObjectName(_fromUtf8("assop3"))
        self.assop3.addItem(_fromUtf8(""))
        self.assop3.addItem(_fromUtf8(""))
        self.assop3.addItem(_fromUtf8(""))
        self.assop3.addItem(_fromUtf8(""))
        self.assop3.addItem(_fromUtf8(""))
        self.assop3.addItem(_fromUtf8(""))
        self.assop3.addItem(_fromUtf8(""))
        self.assop3.addItem(_fromUtf8(""))
        self.assop3.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assop3, 3, 1, 1, 1)
        self.FS3 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FS3.setFont(font)
        self.FS3.setObjectName(_fromUtf8("FS3"))
        self.gridLayout.addWidget(self.FS3, 3, 2, 1, 1)
        self.FN3 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FN3.setFont(font)
        self.FN3.setObjectName(_fromUtf8("FN3"))
        self.gridLayout.addWidget(self.FN3, 3, 3, 1, 1)
        self.FE3 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FE3.setFont(font)
        self.FE3.setObjectName(_fromUtf8("FE3"))
        self.gridLayout.addWidget(self.FE3, 3, 4, 1, 1)
        self.FA3 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FA3.setFont(font)
        self.FA3.setObjectName(_fromUtf8("FA3"))
        self.gridLayout.addWidget(self.FA3, 3, 5, 1, 1)
        self.FC3 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FC3.setFont(font)
        self.FC3.setObjectName(_fromUtf8("FC3"))
        self.gridLayout.addWidget(self.FC3, 3, 6, 1, 1)
        self.FR3 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FR3.setFont(font)
        self.FR3.setObjectName(_fromUtf8("FR3"))
        self.gridLayout.addWidget(self.FR3, 3, 7, 1, 1)
        self.textval3 = QtGui.QLineEdit(self.widget)
        self.textval3.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.textval3.setFont(font)
        self.textval3.setMaxLength(49)
        self.textval3.setObjectName(_fromUtf8("textval3"))
        self.gridLayout.addWidget(self.textval3, 3, 8, 1, 1)
        self.asstext3 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(11)
        self.asstext3.setFont(font)
        self.asstext3.setObjectName(_fromUtf8("asstext3"))
        self.gridLayout.addWidget(self.asstext3, 3, 9, 1, 1)
        self.intval3 = QtGui.QSpinBox(self.widget)
        self.intval3.setMinimum(-1000000)
        self.intval3.setMaximum(1000000)
        self.intval3.setProperty("value", 0)
        self.intval3.setObjectName(_fromUtf8("intval3"))
        self.gridLayout.addWidget(self.intval3, 3, 10, 1, 1)
        self.ac3 = QtGui.QCheckBox(self.widget)
        self.ac3.setObjectName(_fromUtf8("ac3"))
        self.gridLayout.addWidget(self.ac3, 3, 11, 1, 1)
        self.assvar4 = QtGui.QComboBox(self.widget)
        self.assvar4.setObjectName(_fromUtf8("assvar4"))
        self.assvar4.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assvar4, 4, 0, 1, 1)
        self.assop4 = QtGui.QComboBox(self.widget)
        self.assop4.setObjectName(_fromUtf8("assop4"))
        self.assop4.addItem(_fromUtf8(""))
        self.assop4.addItem(_fromUtf8(""))
        self.assop4.addItem(_fromUtf8(""))
        self.assop4.addItem(_fromUtf8(""))
        self.assop4.addItem(_fromUtf8(""))
        self.assop4.addItem(_fromUtf8(""))
        self.assop4.addItem(_fromUtf8(""))
        self.assop4.addItem(_fromUtf8(""))
        self.assop4.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assop4, 4, 1, 1, 1)
        self.FS4 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FS4.setFont(font)
        self.FS4.setObjectName(_fromUtf8("FS4"))
        self.gridLayout.addWidget(self.FS4, 4, 2, 1, 1)
        self.FN4 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FN4.setFont(font)
        self.FN4.setObjectName(_fromUtf8("FN4"))
        self.gridLayout.addWidget(self.FN4, 4, 3, 1, 1)
        self.FE4 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FE4.setFont(font)
        self.FE4.setObjectName(_fromUtf8("FE4"))
        self.gridLayout.addWidget(self.FE4, 4, 4, 1, 1)
        self.FA4 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FA4.setFont(font)
        self.FA4.setObjectName(_fromUtf8("FA4"))
        self.gridLayout.addWidget(self.FA4, 4, 5, 1, 1)
        self.FC4 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FC4.setFont(font)
        self.FC4.setObjectName(_fromUtf8("FC4"))
        self.gridLayout.addWidget(self.FC4, 4, 6, 1, 1)
        self.FR4 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FR4.setFont(font)
        self.FR4.setObjectName(_fromUtf8("FR4"))
        self.gridLayout.addWidget(self.FR4, 4, 7, 1, 1)
        self.textval4 = QtGui.QLineEdit(self.widget)
        self.textval4.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.textval4.setFont(font)
        self.textval4.setMaxLength(49)
        self.textval4.setObjectName(_fromUtf8("textval4"))
        self.gridLayout.addWidget(self.textval4, 4, 8, 1, 1)
        self.asstext4 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(11)
        self.asstext4.setFont(font)
        self.asstext4.setObjectName(_fromUtf8("asstext4"))
        self.gridLayout.addWidget(self.asstext4, 4, 9, 1, 1)
        self.intval4 = QtGui.QSpinBox(self.widget)
        self.intval4.setMinimum(-1000000)
        self.intval4.setMaximum(1000000)
        self.intval4.setProperty("value", 0)
        self.intval4.setObjectName(_fromUtf8("intval4"))
        self.gridLayout.addWidget(self.intval4, 4, 10, 1, 1)
        self.ac4 = QtGui.QCheckBox(self.widget)
        self.ac4.setObjectName(_fromUtf8("ac4"))
        self.gridLayout.addWidget(self.ac4, 4, 11, 1, 1)
        self.assvar5 = QtGui.QComboBox(self.widget)
        self.assvar5.setObjectName(_fromUtf8("assvar5"))
        self.assvar5.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assvar5, 5, 0, 1, 1)
        self.assop5 = QtGui.QComboBox(self.widget)
        self.assop5.setObjectName(_fromUtf8("assop5"))
        self.assop5.addItem(_fromUtf8(""))
        self.assop5.addItem(_fromUtf8(""))
        self.assop5.addItem(_fromUtf8(""))
        self.assop5.addItem(_fromUtf8(""))
        self.assop5.addItem(_fromUtf8(""))
        self.assop5.addItem(_fromUtf8(""))
        self.assop5.addItem(_fromUtf8(""))
        self.assop5.addItem(_fromUtf8(""))
        self.assop5.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assop5, 5, 1, 1, 1)
        self.FS5 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FS5.setFont(font)
        self.FS5.setObjectName(_fromUtf8("FS5"))
        self.gridLayout.addWidget(self.FS5, 5, 2, 1, 1)
        self.FN5 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FN5.setFont(font)
        self.FN5.setObjectName(_fromUtf8("FN5"))
        self.gridLayout.addWidget(self.FN5, 5, 3, 1, 1)
        self.FE5 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FE5.setFont(font)
        self.FE5.setObjectName(_fromUtf8("FE5"))
        self.gridLayout.addWidget(self.FE5, 5, 4, 1, 1)
        self.FA5 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FA5.setFont(font)
        self.FA5.setObjectName(_fromUtf8("FA5"))
        self.gridLayout.addWidget(self.FA5, 5, 5, 1, 1)
        self.FC5 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FC5.setFont(font)
        self.FC5.setObjectName(_fromUtf8("FC5"))
        self.gridLayout.addWidget(self.FC5, 5, 6, 1, 1)
        self.FR5 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FR5.setFont(font)
        self.FR5.setObjectName(_fromUtf8("FR5"))
        self.gridLayout.addWidget(self.FR5, 5, 7, 1, 1)
        self.textval5 = QtGui.QLineEdit(self.widget)
        self.textval5.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.textval5.setFont(font)
        self.textval5.setMaxLength(49)
        self.textval5.setObjectName(_fromUtf8("textval5"))
        self.gridLayout.addWidget(self.textval5, 5, 8, 1, 1)
        self.asstext5 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(11)
        self.asstext5.setFont(font)
        self.asstext5.setObjectName(_fromUtf8("asstext5"))
        self.gridLayout.addWidget(self.asstext5, 5, 9, 1, 1)
        self.intval5 = QtGui.QSpinBox(self.widget)
        self.intval5.setMinimum(-1000000)
        self.intval5.setMaximum(1000000)
        self.intval5.setProperty("value", 0)
        self.intval5.setObjectName(_fromUtf8("intval5"))
        self.gridLayout.addWidget(self.intval5, 5, 10, 1, 1)
        self.ac5 = QtGui.QCheckBox(self.widget)
        self.ac5.setObjectName(_fromUtf8("ac5"))
        self.gridLayout.addWidget(self.ac5, 5, 11, 1, 1)
        self.assvar6 = QtGui.QComboBox(self.widget)
        self.assvar6.setObjectName(_fromUtf8("assvar6"))
        self.assvar6.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assvar6, 6, 0, 1, 1)
        self.assop6 = QtGui.QComboBox(self.widget)
        self.assop6.setObjectName(_fromUtf8("assop6"))
        self.assop6.addItem(_fromUtf8(""))
        self.assop6.addItem(_fromUtf8(""))
        self.assop6.addItem(_fromUtf8(""))
        self.assop6.addItem(_fromUtf8(""))
        self.assop6.addItem(_fromUtf8(""))
        self.assop6.addItem(_fromUtf8(""))
        self.assop6.addItem(_fromUtf8(""))
        self.assop6.addItem(_fromUtf8(""))
        self.assop6.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assop6, 6, 1, 1, 1)
        self.FS6 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FS6.setFont(font)
        self.FS6.setObjectName(_fromUtf8("FS6"))
        self.gridLayout.addWidget(self.FS6, 6, 2, 1, 1)
        self.FN6 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FN6.setFont(font)
        self.FN6.setObjectName(_fromUtf8("FN6"))
        self.gridLayout.addWidget(self.FN6, 6, 3, 1, 1)
        self.FE6 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FE6.setFont(font)
        self.FE6.setObjectName(_fromUtf8("FE6"))
        self.gridLayout.addWidget(self.FE6, 6, 4, 1, 1)
        self.FA6 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FA6.setFont(font)
        self.FA6.setObjectName(_fromUtf8("FA6"))
        self.gridLayout.addWidget(self.FA6, 6, 5, 1, 1)
        self.FC6 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FC6.setFont(font)
        self.FC6.setObjectName(_fromUtf8("FC6"))
        self.gridLayout.addWidget(self.FC6, 6, 6, 1, 1)
        self.FR6 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FR6.setFont(font)
        self.FR6.setObjectName(_fromUtf8("FR6"))
        self.gridLayout.addWidget(self.FR6, 6, 7, 1, 1)
        self.textval6 = QtGui.QLineEdit(self.widget)
        self.textval6.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.textval6.setFont(font)
        self.textval6.setMaxLength(49)
        self.textval6.setObjectName(_fromUtf8("textval6"))
        self.gridLayout.addWidget(self.textval6, 6, 8, 1, 1)
        self.asstext6 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(11)
        self.asstext6.setFont(font)
        self.asstext6.setObjectName(_fromUtf8("asstext6"))
        self.gridLayout.addWidget(self.asstext6, 6, 9, 1, 1)
        self.intval6 = QtGui.QSpinBox(self.widget)
        self.intval6.setMinimum(-1000000)
        self.intval6.setMaximum(1000000)
        self.intval6.setProperty("value", 0)
        self.intval6.setObjectName(_fromUtf8("intval6"))
        self.gridLayout.addWidget(self.intval6, 6, 10, 1, 1)
        self.ac6 = QtGui.QCheckBox(self.widget)
        self.ac6.setObjectName(_fromUtf8("ac6"))
        self.gridLayout.addWidget(self.ac6, 6, 11, 1, 1)
        self.assvar7 = QtGui.QComboBox(self.widget)
        self.assvar7.setObjectName(_fromUtf8("assvar7"))
        self.assvar7.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assvar7, 7, 0, 1, 1)
        self.assop7 = QtGui.QComboBox(self.widget)
        self.assop7.setObjectName(_fromUtf8("assop7"))
        self.assop7.addItem(_fromUtf8(""))
        self.assop7.addItem(_fromUtf8(""))
        self.assop7.addItem(_fromUtf8(""))
        self.assop7.addItem(_fromUtf8(""))
        self.assop7.addItem(_fromUtf8(""))
        self.assop7.addItem(_fromUtf8(""))
        self.assop7.addItem(_fromUtf8(""))
        self.assop7.addItem(_fromUtf8(""))
        self.assop7.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assop7, 7, 1, 1, 1)
        self.FS7 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FS7.setFont(font)
        self.FS7.setObjectName(_fromUtf8("FS7"))
        self.gridLayout.addWidget(self.FS7, 7, 2, 1, 1)
        self.FN7 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FN7.setFont(font)
        self.FN7.setObjectName(_fromUtf8("FN7"))
        self.gridLayout.addWidget(self.FN7, 7, 3, 1, 1)
        self.FE7 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FE7.setFont(font)
        self.FE7.setObjectName(_fromUtf8("FE7"))
        self.gridLayout.addWidget(self.FE7, 7, 4, 1, 1)
        self.FA7 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FA7.setFont(font)
        self.FA7.setObjectName(_fromUtf8("FA7"))
        self.gridLayout.addWidget(self.FA7, 7, 5, 1, 1)
        self.FC7 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FC7.setFont(font)
        self.FC7.setObjectName(_fromUtf8("FC7"))
        self.gridLayout.addWidget(self.FC7, 7, 6, 1, 1)
        self.FR7 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FR7.setFont(font)
        self.FR7.setObjectName(_fromUtf8("FR7"))
        self.gridLayout.addWidget(self.FR7, 7, 7, 1, 1)
        self.textval7 = QtGui.QLineEdit(self.widget)
        self.textval7.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.textval7.setFont(font)
        self.textval7.setMaxLength(49)
        self.textval7.setObjectName(_fromUtf8("textval7"))
        self.gridLayout.addWidget(self.textval7, 7, 8, 1, 1)
        self.asstext7 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(11)
        self.asstext7.setFont(font)
        self.asstext7.setObjectName(_fromUtf8("asstext7"))
        self.gridLayout.addWidget(self.asstext7, 7, 9, 1, 1)
        self.intval7 = QtGui.QSpinBox(self.widget)
        self.intval7.setMinimum(-1000000)
        self.intval7.setMaximum(1000000)
        self.intval7.setProperty("value", 0)
        self.intval7.setObjectName(_fromUtf8("intval7"))
        self.gridLayout.addWidget(self.intval7, 7, 10, 1, 1)
        self.ac7 = QtGui.QCheckBox(self.widget)
        self.ac7.setObjectName(_fromUtf8("ac7"))
        self.gridLayout.addWidget(self.ac7, 7, 11, 1, 1)

        self.retranslateUi(jassdlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), jassdlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), jassdlg.reject)
        QtCore.QMetaObject.connectSlotsByName(jassdlg)
        jassdlg.setTabOrder(self.assvar0, self.assop0)
        jassdlg.setTabOrder(self.assop0, self.FS0)
        jassdlg.setTabOrder(self.FS0, self.FN0)
        jassdlg.setTabOrder(self.FN0, self.FE0)
        jassdlg.setTabOrder(self.FE0, self.FA0)
        jassdlg.setTabOrder(self.FA0, self.FC0)
        jassdlg.setTabOrder(self.FC0, self.FR0)
        jassdlg.setTabOrder(self.FR0, self.textval0)
        jassdlg.setTabOrder(self.textval0, self.asstext0)
        jassdlg.setTabOrder(self.asstext0, self.intval0)
        jassdlg.setTabOrder(self.intval0, self.ac0)
        jassdlg.setTabOrder(self.ac0, self.assvar1)
        jassdlg.setTabOrder(self.assvar1, self.assop1)
        jassdlg.setTabOrder(self.assop1, self.FS1)
        jassdlg.setTabOrder(self.FS1, self.FN1)
        jassdlg.setTabOrder(self.FN1, self.FE1)
        jassdlg.setTabOrder(self.FE1, self.FA1)
        jassdlg.setTabOrder(self.FA1, self.FC1)
        jassdlg.setTabOrder(self.FC1, self.FR1)
        jassdlg.setTabOrder(self.FR1, self.textval1)
        jassdlg.setTabOrder(self.textval1, self.asstext1)
        jassdlg.setTabOrder(self.asstext1, self.intval1)
        jassdlg.setTabOrder(self.intval1, self.ac1)
        jassdlg.setTabOrder(self.ac1, self.assvar2)
        jassdlg.setTabOrder(self.assvar2, self.assop2)
        jassdlg.setTabOrder(self.assop2, self.FS2)
        jassdlg.setTabOrder(self.FS2, self.FN2)
        jassdlg.setTabOrder(self.FN2, self.FE2)
        jassdlg.setTabOrder(self.FE2, self.FA2)
        jassdlg.setTabOrder(self.FA2, self.FC2)
        jassdlg.setTabOrder(self.FC2, self.FR2)
        jassdlg.setTabOrder(self.FR2, self.textval2)
        jassdlg.setTabOrder(self.textval2, self.asstext2)
        jassdlg.setTabOrder(self.asstext2, self.intval2)
        jassdlg.setTabOrder(self.intval2, self.ac2)
        jassdlg.setTabOrder(self.ac2, self.assvar3)
        jassdlg.setTabOrder(self.assvar3, self.assop3)
        jassdlg.setTabOrder(self.assop3, self.FS3)
        jassdlg.setTabOrder(self.FS3, self.FN3)
        jassdlg.setTabOrder(self.FN3, self.FE3)
        jassdlg.setTabOrder(self.FE3, self.FA3)
        jassdlg.setTabOrder(self.FA3, self.FC3)
        jassdlg.setTabOrder(self.FC3, self.FR3)
        jassdlg.setTabOrder(self.FR3, self.textval3)
        jassdlg.setTabOrder(self.textval3, self.asstext3)
        jassdlg.setTabOrder(self.asstext3, self.intval3)
        jassdlg.setTabOrder(self.intval3, self.ac3)
        jassdlg.setTabOrder(self.ac3, self.assvar4)
        jassdlg.setTabOrder(self.assvar4, self.assop4)
        jassdlg.setTabOrder(self.assop4, self.FS4)
        jassdlg.setTabOrder(self.FS4, self.FN4)
        jassdlg.setTabOrder(self.FN4, self.FE4)
        jassdlg.setTabOrder(self.FE4, self.FA4)
        jassdlg.setTabOrder(self.FA4, self.FC4)
        jassdlg.setTabOrder(self.FC4, self.FR4)
        jassdlg.setTabOrder(self.FR4, self.textval4)
        jassdlg.setTabOrder(self.textval4, self.asstext4)
        jassdlg.setTabOrder(self.asstext4, self.intval4)
        jassdlg.setTabOrder(self.intval4, self.ac4)
        jassdlg.setTabOrder(self.ac4, self.assvar5)
        jassdlg.setTabOrder(self.assvar5, self.assop5)
        jassdlg.setTabOrder(self.assop5, self.FS5)
        jassdlg.setTabOrder(self.FS5, self.FN5)
        jassdlg.setTabOrder(self.FN5, self.FE5)
        jassdlg.setTabOrder(self.FE5, self.FA5)
        jassdlg.setTabOrder(self.FA5, self.FC5)
        jassdlg.setTabOrder(self.FC5, self.FR5)
        jassdlg.setTabOrder(self.FR5, self.textval5)
        jassdlg.setTabOrder(self.textval5, self.asstext5)
        jassdlg.setTabOrder(self.asstext5, self.intval5)
        jassdlg.setTabOrder(self.intval5, self.ac5)
        jassdlg.setTabOrder(self.ac5, self.assvar6)
        jassdlg.setTabOrder(self.assvar6, self.assop6)
        jassdlg.setTabOrder(self.assop6, self.FS6)
        jassdlg.setTabOrder(self.FS6, self.FN6)
        jassdlg.setTabOrder(self.FN6, self.FE6)
        jassdlg.setTabOrder(self.FE6, self.FA6)
        jassdlg.setTabOrder(self.FA6, self.FC6)
        jassdlg.setTabOrder(self.FC6, self.FR6)
        jassdlg.setTabOrder(self.FR6, self.textval6)
        jassdlg.setTabOrder(self.textval6, self.asstext6)
        jassdlg.setTabOrder(self.asstext6, self.intval6)
        jassdlg.setTabOrder(self.intval6, self.ac6)
        jassdlg.setTabOrder(self.ac6, self.assvar7)
        jassdlg.setTabOrder(self.assvar7, self.assop7)
        jassdlg.setTabOrder(self.assop7, self.FS7)
        jassdlg.setTabOrder(self.FS7, self.FN7)
        jassdlg.setTabOrder(self.FN7, self.FE7)
        jassdlg.setTabOrder(self.FE7, self.FA7)
        jassdlg.setTabOrder(self.FA7, self.FC7)
        jassdlg.setTabOrder(self.FC7, self.FR7)
        jassdlg.setTabOrder(self.FR7, self.textval7)
        jassdlg.setTabOrder(self.textval7, self.asstext7)
        jassdlg.setTabOrder(self.asstext7, self.intval7)
        jassdlg.setTabOrder(self.intval7, self.ac7)
        jassdlg.setTabOrder(self.ac7, self.buttonBox)

    def retranslateUi(self, jassdlg):
        jassdlg.setWindowTitle(QtGui.QApplication.translate("jassdlg", "Assignments for job", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("jassdlg", "Assignments for job", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("jassdlg", "Variable", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("jassdlg", "Op", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("jassdlg", "When Done", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("jassdlg", "Text Value", None, QtGui.QApplication.UnicodeUTF8))
        self.label_6.setText(QtGui.QApplication.translate("jassdlg", "Int Val", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar0.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the variable to be assigned to", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar0.setItemText(0, QtGui.QApplication.translate("jassdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop0.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the operation to be performed", None, QtGui.QApplication.UnicodeUTF8))
        self.assop0.setItemText(0, QtGui.QApplication.translate("jassdlg", "(none)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop0.setItemText(1, QtGui.QApplication.translate("jassdlg", "Set", None, QtGui.QApplication.UnicodeUTF8))
        self.assop0.setItemText(2, QtGui.QApplication.translate("jassdlg", "Add", None, QtGui.QApplication.UnicodeUTF8))
        self.assop0.setItemText(3, QtGui.QApplication.translate("jassdlg", "Subtract", None, QtGui.QApplication.UnicodeUTF8))
        self.assop0.setItemText(4, QtGui.QApplication.translate("jassdlg", "Multiply", None, QtGui.QApplication.UnicodeUTF8))
        self.assop0.setItemText(5, QtGui.QApplication.translate("jassdlg", "Divide", None, QtGui.QApplication.UnicodeUTF8))
        self.assop0.setItemText(6, QtGui.QApplication.translate("jassdlg", "Modulus", None, QtGui.QApplication.UnicodeUTF8))
        self.assop0.setItemText(7, QtGui.QApplication.translate("jassdlg", "Set Exit", None, QtGui.QApplication.UnicodeUTF8))
        self.assop0.setItemText(8, QtGui.QApplication.translate("jassdlg", "Set Signal", None, QtGui.QApplication.UnicodeUTF8))
        self.FS0.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job starts", None, QtGui.QApplication.UnicodeUTF8))
        self.FS0.setText(QtGui.QApplication.translate("jassdlg", "S", None, QtGui.QApplication.UnicodeUTF8))
        self.FN0.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits normally (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FN0.setText(QtGui.QApplication.translate("jassdlg", "N", None, QtGui.QApplication.UnicodeUTF8))
        self.FE0.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits with an error code (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FE0.setText(QtGui.QApplication.translate("jassdlg", "E", None, QtGui.QApplication.UnicodeUTF8))
        self.FA0.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"aborts - either exits with a signal, or with an error code not covered\n"
"by the job exit code settings.", None, QtGui.QApplication.UnicodeUTF8))
        self.FA0.setText(QtGui.QApplication.translate("jassdlg", "A", None, QtGui.QApplication.UnicodeUTF8))
        self.FC0.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"is cancelled (killed with a signal before it is run).", None, QtGui.QApplication.UnicodeUTF8))
        self.FC0.setText(QtGui.QApplication.translate("jassdlg", "C", None, QtGui.QApplication.UnicodeUTF8))
        self.FR0.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the exit code operations (N E A C) are to be reversed if\n"
"possible.\n"
"\n"
"Note that only add subtract multiply and divide can be reversed.", None, QtGui.QApplication.UnicodeUTF8))
        self.FR0.setText(QtGui.QApplication.translate("jassdlg", "R", None, QtGui.QApplication.UnicodeUTF8))
        self.textval0.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the text value to be assigned here", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext0.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicate that the value to be assigned is text", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext0.setText(QtGui.QApplication.translate("jassdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.intval0.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the integer value to be used here", None, QtGui.QApplication.UnicodeUTF8))
        self.ac0.setToolTip(QtGui.QApplication.translate("jassdlg", "This is a critical assignment\n"
"\n"
"If set and the host with the variable is not running, then the job is held.\n"
"\n"
"If it is not set and the host with the variable is not running, then the\n"
"assignment is ignored.", None, QtGui.QApplication.UnicodeUTF8))
        self.ac0.setText(QtGui.QApplication.translate("jassdlg", "Acrit", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar1.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the variable to be assigned to", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar1.setItemText(0, QtGui.QApplication.translate("jassdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop1.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the operation to be performed", None, QtGui.QApplication.UnicodeUTF8))
        self.assop1.setItemText(0, QtGui.QApplication.translate("jassdlg", "(none)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop1.setItemText(1, QtGui.QApplication.translate("jassdlg", "Set", None, QtGui.QApplication.UnicodeUTF8))
        self.assop1.setItemText(2, QtGui.QApplication.translate("jassdlg", "Add", None, QtGui.QApplication.UnicodeUTF8))
        self.assop1.setItemText(3, QtGui.QApplication.translate("jassdlg", "Subtract", None, QtGui.QApplication.UnicodeUTF8))
        self.assop1.setItemText(4, QtGui.QApplication.translate("jassdlg", "Multiply", None, QtGui.QApplication.UnicodeUTF8))
        self.assop1.setItemText(5, QtGui.QApplication.translate("jassdlg", "Divide", None, QtGui.QApplication.UnicodeUTF8))
        self.assop1.setItemText(6, QtGui.QApplication.translate("jassdlg", "Modulus", None, QtGui.QApplication.UnicodeUTF8))
        self.assop1.setItemText(7, QtGui.QApplication.translate("jassdlg", "Set Exit", None, QtGui.QApplication.UnicodeUTF8))
        self.assop1.setItemText(8, QtGui.QApplication.translate("jassdlg", "Set Signal", None, QtGui.QApplication.UnicodeUTF8))
        self.FS1.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job starts", None, QtGui.QApplication.UnicodeUTF8))
        self.FS1.setText(QtGui.QApplication.translate("jassdlg", "S", None, QtGui.QApplication.UnicodeUTF8))
        self.FN1.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits normally (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FN1.setText(QtGui.QApplication.translate("jassdlg", "N", None, QtGui.QApplication.UnicodeUTF8))
        self.FE1.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits with an error code (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FE1.setText(QtGui.QApplication.translate("jassdlg", "E", None, QtGui.QApplication.UnicodeUTF8))
        self.FA1.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"aborts - either exits with a signal, or with an error code not covered\n"
"by the job exit code settings.", None, QtGui.QApplication.UnicodeUTF8))
        self.FA1.setText(QtGui.QApplication.translate("jassdlg", "A", None, QtGui.QApplication.UnicodeUTF8))
        self.FC1.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"is cancelled (killed with a signal before it is run).", None, QtGui.QApplication.UnicodeUTF8))
        self.FC1.setText(QtGui.QApplication.translate("jassdlg", "C", None, QtGui.QApplication.UnicodeUTF8))
        self.FR1.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the exit code operations (N E A C) are to be reversed if\n"
"possible.\n"
"\n"
"Note that only add subtract multiply and divide can be reversed.", None, QtGui.QApplication.UnicodeUTF8))
        self.FR1.setText(QtGui.QApplication.translate("jassdlg", "R", None, QtGui.QApplication.UnicodeUTF8))
        self.textval1.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the text value to be assigned here", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext1.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicate that the value to be assigned is text", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext1.setText(QtGui.QApplication.translate("jassdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.intval1.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the integer value to be used here", None, QtGui.QApplication.UnicodeUTF8))
        self.ac1.setToolTip(QtGui.QApplication.translate("jassdlg", "This is a critical assignment\n"
"\n"
"If set and the host with the variable is not running, then the job is held.\n"
"\n"
"If it is not set and the host with the variable is not running, then the\n"
"assignment is ignored.", None, QtGui.QApplication.UnicodeUTF8))
        self.ac1.setText(QtGui.QApplication.translate("jassdlg", "Acrit", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar2.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the variable to be assigned to", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar2.setItemText(0, QtGui.QApplication.translate("jassdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop2.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the operation to be performed", None, QtGui.QApplication.UnicodeUTF8))
        self.assop2.setItemText(0, QtGui.QApplication.translate("jassdlg", "(none)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop2.setItemText(1, QtGui.QApplication.translate("jassdlg", "Set", None, QtGui.QApplication.UnicodeUTF8))
        self.assop2.setItemText(2, QtGui.QApplication.translate("jassdlg", "Add", None, QtGui.QApplication.UnicodeUTF8))
        self.assop2.setItemText(3, QtGui.QApplication.translate("jassdlg", "Subtract", None, QtGui.QApplication.UnicodeUTF8))
        self.assop2.setItemText(4, QtGui.QApplication.translate("jassdlg", "Multiply", None, QtGui.QApplication.UnicodeUTF8))
        self.assop2.setItemText(5, QtGui.QApplication.translate("jassdlg", "Divide", None, QtGui.QApplication.UnicodeUTF8))
        self.assop2.setItemText(6, QtGui.QApplication.translate("jassdlg", "Modulus", None, QtGui.QApplication.UnicodeUTF8))
        self.assop2.setItemText(7, QtGui.QApplication.translate("jassdlg", "Set Exit", None, QtGui.QApplication.UnicodeUTF8))
        self.assop2.setItemText(8, QtGui.QApplication.translate("jassdlg", "Set Signal", None, QtGui.QApplication.UnicodeUTF8))
        self.FS2.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job starts", None, QtGui.QApplication.UnicodeUTF8))
        self.FS2.setText(QtGui.QApplication.translate("jassdlg", "S", None, QtGui.QApplication.UnicodeUTF8))
        self.FN2.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits normally (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FN2.setText(QtGui.QApplication.translate("jassdlg", "N", None, QtGui.QApplication.UnicodeUTF8))
        self.FE2.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits with an error code (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FE2.setText(QtGui.QApplication.translate("jassdlg", "E", None, QtGui.QApplication.UnicodeUTF8))
        self.FA2.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"aborts - either exits with a signal, or with an error code not covered\n"
"by the job exit code settings.", None, QtGui.QApplication.UnicodeUTF8))
        self.FA2.setText(QtGui.QApplication.translate("jassdlg", "A", None, QtGui.QApplication.UnicodeUTF8))
        self.FC2.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"is cancelled (killed with a signal before it is run).", None, QtGui.QApplication.UnicodeUTF8))
        self.FC2.setText(QtGui.QApplication.translate("jassdlg", "C", None, QtGui.QApplication.UnicodeUTF8))
        self.FR2.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the exit code operations (N E A C) are to be reversed if\n"
"possible.\n"
"\n"
"Note that only add subtract multiply and divide can be reversed.", None, QtGui.QApplication.UnicodeUTF8))
        self.FR2.setText(QtGui.QApplication.translate("jassdlg", "R", None, QtGui.QApplication.UnicodeUTF8))
        self.textval2.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the text value to be assigned here", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext2.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicate that the value to be assigned is text", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext2.setText(QtGui.QApplication.translate("jassdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.intval2.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the integer value to be used here", None, QtGui.QApplication.UnicodeUTF8))
        self.ac2.setToolTip(QtGui.QApplication.translate("jassdlg", "This is a critical assignment\n"
"\n"
"If set and the host with the variable is not running, then the job is held.\n"
"\n"
"If it is not set and the host with the variable is not running, then the\n"
"assignment is ignored.", None, QtGui.QApplication.UnicodeUTF8))
        self.ac2.setText(QtGui.QApplication.translate("jassdlg", "Acrit", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar3.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the variable to be assigned to", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar3.setItemText(0, QtGui.QApplication.translate("jassdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop3.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the operation to be performed", None, QtGui.QApplication.UnicodeUTF8))
        self.assop3.setItemText(0, QtGui.QApplication.translate("jassdlg", "(none)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop3.setItemText(1, QtGui.QApplication.translate("jassdlg", "Set", None, QtGui.QApplication.UnicodeUTF8))
        self.assop3.setItemText(2, QtGui.QApplication.translate("jassdlg", "Add", None, QtGui.QApplication.UnicodeUTF8))
        self.assop3.setItemText(3, QtGui.QApplication.translate("jassdlg", "Subtract", None, QtGui.QApplication.UnicodeUTF8))
        self.assop3.setItemText(4, QtGui.QApplication.translate("jassdlg", "Multiply", None, QtGui.QApplication.UnicodeUTF8))
        self.assop3.setItemText(5, QtGui.QApplication.translate("jassdlg", "Divide", None, QtGui.QApplication.UnicodeUTF8))
        self.assop3.setItemText(6, QtGui.QApplication.translate("jassdlg", "Modulus", None, QtGui.QApplication.UnicodeUTF8))
        self.assop3.setItemText(7, QtGui.QApplication.translate("jassdlg", "Set Exit", None, QtGui.QApplication.UnicodeUTF8))
        self.assop3.setItemText(8, QtGui.QApplication.translate("jassdlg", "Set Signal", None, QtGui.QApplication.UnicodeUTF8))
        self.FS3.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job starts", None, QtGui.QApplication.UnicodeUTF8))
        self.FS3.setText(QtGui.QApplication.translate("jassdlg", "S", None, QtGui.QApplication.UnicodeUTF8))
        self.FN3.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits normally (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FN3.setText(QtGui.QApplication.translate("jassdlg", "N", None, QtGui.QApplication.UnicodeUTF8))
        self.FE3.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits with an error code (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FE3.setText(QtGui.QApplication.translate("jassdlg", "E", None, QtGui.QApplication.UnicodeUTF8))
        self.FA3.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"aborts - either exits with a signal, or with an error code not covered\n"
"by the job exit code settings.", None, QtGui.QApplication.UnicodeUTF8))
        self.FA3.setText(QtGui.QApplication.translate("jassdlg", "A", None, QtGui.QApplication.UnicodeUTF8))
        self.FC3.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"is cancelled (killed with a signal before it is run).", None, QtGui.QApplication.UnicodeUTF8))
        self.FC3.setText(QtGui.QApplication.translate("jassdlg", "C", None, QtGui.QApplication.UnicodeUTF8))
        self.FR3.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the exit code operations (N E A C) are to be reversed if\n"
"possible.\n"
"\n"
"Note that only add subtract multiply and divide can be reversed.", None, QtGui.QApplication.UnicodeUTF8))
        self.FR3.setText(QtGui.QApplication.translate("jassdlg", "R", None, QtGui.QApplication.UnicodeUTF8))
        self.textval3.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the text value to be assigned here", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext3.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicate that the value to be assigned is text", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext3.setText(QtGui.QApplication.translate("jassdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.intval3.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the integer value to be used here", None, QtGui.QApplication.UnicodeUTF8))
        self.ac3.setToolTip(QtGui.QApplication.translate("jassdlg", "This is a critical assignment\n"
"\n"
"If set and the host with the variable is not running, then the job is held.\n"
"\n"
"If it is not set and the host with the variable is not running, then the\n"
"assignment is ignored.", None, QtGui.QApplication.UnicodeUTF8))
        self.ac3.setText(QtGui.QApplication.translate("jassdlg", "Acrit", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar4.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the variable to be assigned to", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar4.setItemText(0, QtGui.QApplication.translate("jassdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop4.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the operation to be performed", None, QtGui.QApplication.UnicodeUTF8))
        self.assop4.setItemText(0, QtGui.QApplication.translate("jassdlg", "(none)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop4.setItemText(1, QtGui.QApplication.translate("jassdlg", "Set", None, QtGui.QApplication.UnicodeUTF8))
        self.assop4.setItemText(2, QtGui.QApplication.translate("jassdlg", "Add", None, QtGui.QApplication.UnicodeUTF8))
        self.assop4.setItemText(3, QtGui.QApplication.translate("jassdlg", "Subtract", None, QtGui.QApplication.UnicodeUTF8))
        self.assop4.setItemText(4, QtGui.QApplication.translate("jassdlg", "Multiply", None, QtGui.QApplication.UnicodeUTF8))
        self.assop4.setItemText(5, QtGui.QApplication.translate("jassdlg", "Divide", None, QtGui.QApplication.UnicodeUTF8))
        self.assop4.setItemText(6, QtGui.QApplication.translate("jassdlg", "Modulus", None, QtGui.QApplication.UnicodeUTF8))
        self.assop4.setItemText(7, QtGui.QApplication.translate("jassdlg", "Set Exit", None, QtGui.QApplication.UnicodeUTF8))
        self.assop4.setItemText(8, QtGui.QApplication.translate("jassdlg", "Set Signal", None, QtGui.QApplication.UnicodeUTF8))
        self.FS4.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job starts", None, QtGui.QApplication.UnicodeUTF8))
        self.FS4.setText(QtGui.QApplication.translate("jassdlg", "S", None, QtGui.QApplication.UnicodeUTF8))
        self.FN4.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits normally (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FN4.setText(QtGui.QApplication.translate("jassdlg", "N", None, QtGui.QApplication.UnicodeUTF8))
        self.FE4.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits with an error code (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FE4.setText(QtGui.QApplication.translate("jassdlg", "E", None, QtGui.QApplication.UnicodeUTF8))
        self.FA4.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"aborts - either exits with a signal, or with an error code not covered\n"
"by the job exit code settings.", None, QtGui.QApplication.UnicodeUTF8))
        self.FA4.setText(QtGui.QApplication.translate("jassdlg", "A", None, QtGui.QApplication.UnicodeUTF8))
        self.FC4.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"is cancelled (killed with a signal before it is run).", None, QtGui.QApplication.UnicodeUTF8))
        self.FC4.setText(QtGui.QApplication.translate("jassdlg", "C", None, QtGui.QApplication.UnicodeUTF8))
        self.FR4.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the exit code operations (N E A C) are to be reversed if\n"
"possible.\n"
"\n"
"Note that only add subtract multiply and divide can be reversed.", None, QtGui.QApplication.UnicodeUTF8))
        self.FR4.setText(QtGui.QApplication.translate("jassdlg", "R", None, QtGui.QApplication.UnicodeUTF8))
        self.textval4.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the text value to be assigned here", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext4.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicate that the value to be assigned is text", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext4.setText(QtGui.QApplication.translate("jassdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.intval4.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the integer value to be used here", None, QtGui.QApplication.UnicodeUTF8))
        self.ac4.setToolTip(QtGui.QApplication.translate("jassdlg", "This is a critical assignment\n"
"\n"
"If set and the host with the variable is not running, then the job is held.\n"
"\n"
"If it is not set and the host with the variable is not running, then the\n"
"assignment is ignored.", None, QtGui.QApplication.UnicodeUTF8))
        self.ac4.setText(QtGui.QApplication.translate("jassdlg", "Acrit", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar5.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the variable to be assigned to", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar5.setItemText(0, QtGui.QApplication.translate("jassdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop5.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the operation to be performed", None, QtGui.QApplication.UnicodeUTF8))
        self.assop5.setItemText(0, QtGui.QApplication.translate("jassdlg", "(none)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop5.setItemText(1, QtGui.QApplication.translate("jassdlg", "Set", None, QtGui.QApplication.UnicodeUTF8))
        self.assop5.setItemText(2, QtGui.QApplication.translate("jassdlg", "Add", None, QtGui.QApplication.UnicodeUTF8))
        self.assop5.setItemText(3, QtGui.QApplication.translate("jassdlg", "Subtract", None, QtGui.QApplication.UnicodeUTF8))
        self.assop5.setItemText(4, QtGui.QApplication.translate("jassdlg", "Multiply", None, QtGui.QApplication.UnicodeUTF8))
        self.assop5.setItemText(5, QtGui.QApplication.translate("jassdlg", "Divide", None, QtGui.QApplication.UnicodeUTF8))
        self.assop5.setItemText(6, QtGui.QApplication.translate("jassdlg", "Modulus", None, QtGui.QApplication.UnicodeUTF8))
        self.assop5.setItemText(7, QtGui.QApplication.translate("jassdlg", "Set Exit", None, QtGui.QApplication.UnicodeUTF8))
        self.assop5.setItemText(8, QtGui.QApplication.translate("jassdlg", "Set Signal", None, QtGui.QApplication.UnicodeUTF8))
        self.FS5.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job starts", None, QtGui.QApplication.UnicodeUTF8))
        self.FS5.setText(QtGui.QApplication.translate("jassdlg", "S", None, QtGui.QApplication.UnicodeUTF8))
        self.FN5.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits normally (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FN5.setText(QtGui.QApplication.translate("jassdlg", "N", None, QtGui.QApplication.UnicodeUTF8))
        self.FE5.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits with an error code (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FE5.setText(QtGui.QApplication.translate("jassdlg", "E", None, QtGui.QApplication.UnicodeUTF8))
        self.FA5.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"aborts - either exits with a signal, or with an error code not covered\n"
"by the job exit code settings.", None, QtGui.QApplication.UnicodeUTF8))
        self.FA5.setText(QtGui.QApplication.translate("jassdlg", "A", None, QtGui.QApplication.UnicodeUTF8))
        self.FC5.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"is cancelled (killed with a signal before it is run).", None, QtGui.QApplication.UnicodeUTF8))
        self.FC5.setText(QtGui.QApplication.translate("jassdlg", "C", None, QtGui.QApplication.UnicodeUTF8))
        self.FR5.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the exit code operations (N E A C) are to be reversed if\n"
"possible.\n"
"\n"
"Note that only add subtract multiply and divide can be reversed.", None, QtGui.QApplication.UnicodeUTF8))
        self.FR5.setText(QtGui.QApplication.translate("jassdlg", "R", None, QtGui.QApplication.UnicodeUTF8))
        self.textval5.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the text value to be assigned here", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext5.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicate that the value to be assigned is text", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext5.setText(QtGui.QApplication.translate("jassdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.intval5.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the integer value to be used here", None, QtGui.QApplication.UnicodeUTF8))
        self.ac5.setToolTip(QtGui.QApplication.translate("jassdlg", "This is a critical assignment\n"
"\n"
"If set and the host with the variable is not running, then the job is held.\n"
"\n"
"If it is not set and the host with the variable is not running, then the\n"
"assignment is ignored.", None, QtGui.QApplication.UnicodeUTF8))
        self.ac5.setText(QtGui.QApplication.translate("jassdlg", "Acrit", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar6.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the variable to be assigned to", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar6.setItemText(0, QtGui.QApplication.translate("jassdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop6.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the operation to be performed", None, QtGui.QApplication.UnicodeUTF8))
        self.assop6.setItemText(0, QtGui.QApplication.translate("jassdlg", "(none)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop6.setItemText(1, QtGui.QApplication.translate("jassdlg", "Set", None, QtGui.QApplication.UnicodeUTF8))
        self.assop6.setItemText(2, QtGui.QApplication.translate("jassdlg", "Add", None, QtGui.QApplication.UnicodeUTF8))
        self.assop6.setItemText(3, QtGui.QApplication.translate("jassdlg", "Subtract", None, QtGui.QApplication.UnicodeUTF8))
        self.assop6.setItemText(4, QtGui.QApplication.translate("jassdlg", "Multiply", None, QtGui.QApplication.UnicodeUTF8))
        self.assop6.setItemText(5, QtGui.QApplication.translate("jassdlg", "Divide", None, QtGui.QApplication.UnicodeUTF8))
        self.assop6.setItemText(6, QtGui.QApplication.translate("jassdlg", "Modulus", None, QtGui.QApplication.UnicodeUTF8))
        self.assop6.setItemText(7, QtGui.QApplication.translate("jassdlg", "Set Exit", None, QtGui.QApplication.UnicodeUTF8))
        self.assop6.setItemText(8, QtGui.QApplication.translate("jassdlg", "Set Signal", None, QtGui.QApplication.UnicodeUTF8))
        self.FS6.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job starts", None, QtGui.QApplication.UnicodeUTF8))
        self.FS6.setText(QtGui.QApplication.translate("jassdlg", "S", None, QtGui.QApplication.UnicodeUTF8))
        self.FN6.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits normally (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FN6.setText(QtGui.QApplication.translate("jassdlg", "N", None, QtGui.QApplication.UnicodeUTF8))
        self.FE6.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits with an error code (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FE6.setText(QtGui.QApplication.translate("jassdlg", "E", None, QtGui.QApplication.UnicodeUTF8))
        self.FA6.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"aborts - either exits with a signal, or with an error code not covered\n"
"by the job exit code settings.", None, QtGui.QApplication.UnicodeUTF8))
        self.FA6.setText(QtGui.QApplication.translate("jassdlg", "A", None, QtGui.QApplication.UnicodeUTF8))
        self.FC6.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"is cancelled (killed with a signal before it is run).", None, QtGui.QApplication.UnicodeUTF8))
        self.FC6.setText(QtGui.QApplication.translate("jassdlg", "C", None, QtGui.QApplication.UnicodeUTF8))
        self.FR6.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the exit code operations (N E A C) are to be reversed if\n"
"possible.\n"
"\n"
"Note that only add subtract multiply and divide can be reversed.", None, QtGui.QApplication.UnicodeUTF8))
        self.FR6.setText(QtGui.QApplication.translate("jassdlg", "R", None, QtGui.QApplication.UnicodeUTF8))
        self.textval6.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the text value to be assigned here", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext6.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicate that the value to be assigned is text", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext6.setText(QtGui.QApplication.translate("jassdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.intval6.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the integer value to be used here", None, QtGui.QApplication.UnicodeUTF8))
        self.ac6.setToolTip(QtGui.QApplication.translate("jassdlg", "This is a critical assignment\n"
"\n"
"If set and the host with the variable is not running, then the job is held.\n"
"\n"
"If it is not set and the host with the variable is not running, then the\n"
"assignment is ignored.", None, QtGui.QApplication.UnicodeUTF8))
        self.ac6.setText(QtGui.QApplication.translate("jassdlg", "Acrit", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar7.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the variable to be assigned to", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar7.setItemText(0, QtGui.QApplication.translate("jassdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop7.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the operation to be performed", None, QtGui.QApplication.UnicodeUTF8))
        self.assop7.setItemText(0, QtGui.QApplication.translate("jassdlg", "(none)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop7.setItemText(1, QtGui.QApplication.translate("jassdlg", "Set", None, QtGui.QApplication.UnicodeUTF8))
        self.assop7.setItemText(2, QtGui.QApplication.translate("jassdlg", "Add", None, QtGui.QApplication.UnicodeUTF8))
        self.assop7.setItemText(3, QtGui.QApplication.translate("jassdlg", "Subtract", None, QtGui.QApplication.UnicodeUTF8))
        self.assop7.setItemText(4, QtGui.QApplication.translate("jassdlg", "Multiply", None, QtGui.QApplication.UnicodeUTF8))
        self.assop7.setItemText(5, QtGui.QApplication.translate("jassdlg", "Divide", None, QtGui.QApplication.UnicodeUTF8))
        self.assop7.setItemText(6, QtGui.QApplication.translate("jassdlg", "Modulus", None, QtGui.QApplication.UnicodeUTF8))
        self.assop7.setItemText(7, QtGui.QApplication.translate("jassdlg", "Set Exit", None, QtGui.QApplication.UnicodeUTF8))
        self.assop7.setItemText(8, QtGui.QApplication.translate("jassdlg", "Set Signal", None, QtGui.QApplication.UnicodeUTF8))
        self.FS7.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job starts", None, QtGui.QApplication.UnicodeUTF8))
        self.FS7.setText(QtGui.QApplication.translate("jassdlg", "S", None, QtGui.QApplication.UnicodeUTF8))
        self.FN7.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits normally (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FN7.setText(QtGui.QApplication.translate("jassdlg", "N", None, QtGui.QApplication.UnicodeUTF8))
        self.FE7.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits with an error code (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FE7.setText(QtGui.QApplication.translate("jassdlg", "E", None, QtGui.QApplication.UnicodeUTF8))
        self.FA7.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"aborts - either exits with a signal, or with an error code not covered\n"
"by the job exit code settings.", None, QtGui.QApplication.UnicodeUTF8))
        self.FA7.setText(QtGui.QApplication.translate("jassdlg", "A", None, QtGui.QApplication.UnicodeUTF8))
        self.FC7.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"is cancelled (killed with a signal before it is run).", None, QtGui.QApplication.UnicodeUTF8))
        self.FC7.setText(QtGui.QApplication.translate("jassdlg", "C", None, QtGui.QApplication.UnicodeUTF8))
        self.FR7.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the exit code operations (N E A C) are to be reversed if\n"
"possible.\n"
"\n"
"Note that only add subtract multiply and divide can be reversed.", None, QtGui.QApplication.UnicodeUTF8))
        self.FR7.setText(QtGui.QApplication.translate("jassdlg", "R", None, QtGui.QApplication.UnicodeUTF8))
        self.textval7.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the text value to be assigned here", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext7.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicate that the value to be assigned is text", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext7.setText(QtGui.QApplication.translate("jassdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.intval7.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the integer value to be used here", None, QtGui.QApplication.UnicodeUTF8))
        self.ac7.setToolTip(QtGui.QApplication.translate("jassdlg", "This is a critical assignment\n"
"\n"
"If set and the host with the variable is not running, then the job is held.\n"
"\n"
"If it is not set and the host with the variable is not running, then the\n"
"assignment is ignored.", None, QtGui.QApplication.UnicodeUTF8))
        self.ac7.setText(QtGui.QApplication.translate("jassdlg", "Acrit", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'jssearchdlg.ui'
#
# Created: Tue Aug 14 11:40:54 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_jssearchdlg(object):
    def setupUi(self, jssearchdlg):
        jssearchdlg.setObjectName(_fromUtf8("jssearchdlg"))
        jssearchdlg.resize(400, 234)
        self.buttonBox = QtGui.QDialogButtonBox(jssearchdlg)
        self.buttonBox.setGeometry(QtCore.QRect(310, 10, 81, 101))
        self.buttonBox.setOrientation(QtCore.Qt.Vertical)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.groupBox = QtGui.QGroupBox(jssearchdlg)
        self.groupBox.setGeometry(QtCore.QRect(30, 130, 120, 80))
        self.groupBox.setObjectName(_fromUtf8("groupBox"))
        self.sforward = QtGui.QRadioButton(self.groupBox)
        self.sforward.setGeometry(QtCore.QRect(10, 30, 108, 23))
        self.sforward.setChecked(True)
        self.sforward.setObjectName(_fromUtf8("sforward"))
        self.sbackward = QtGui.QRadioButton(self.groupBox)
        self.sbackward.setGeometry(QtCore.QRect(10, 60, 108, 21))
        self.sbackward.setObjectName(_fromUtf8("sbackward"))
        self.wrapround = QtGui.QCheckBox(jssearchdlg)
        self.wrapround.setGeometry(QtCore.QRect(210, 160, 111, 23))
        self.wrapround.setObjectName(_fromUtf8("wrapround"))
        self.label = QtGui.QLabel(jssearchdlg)
        self.label.setGeometry(QtCore.QRect(10, 30, 81, 18))
        self.label.setObjectName(_fromUtf8("label"))
        self.searchstring = QtGui.QLineEdit(jssearchdlg)
        self.searchstring.setGeometry(QtCore.QRect(10, 60, 251, 26))
        self.searchstring.setObjectName(_fromUtf8("searchstring"))
        self.igncase = QtGui.QCheckBox(jssearchdlg)
        self.igncase.setGeometry(QtCore.QRect(210, 190, 121, 23))
        self.igncase.setChecked(True)
        self.igncase.setObjectName(_fromUtf8("igncase"))
        self.layoutWidget = QtGui.QWidget(jssearchdlg)
        self.layoutWidget.setGeometry(QtCore.QRect(0, 0, 2, 2))
        self.layoutWidget.setObjectName(_fromUtf8("layoutWidget"))
        self.verticalLayout = QtGui.QVBoxLayout(self.layoutWidget)
        self.verticalLayout.setMargin(0)
        self.verticalLayout.setObjectName(_fromUtf8("verticalLayout"))
        self.layoutWidget1 = QtGui.QWidget(jssearchdlg)
        self.layoutWidget1.setGeometry(QtCore.QRect(0, 0, 2, 2))
        self.layoutWidget1.setObjectName(_fromUtf8("layoutWidget1"))
        self.verticalLayout_2 = QtGui.QVBoxLayout(self.layoutWidget1)
        self.verticalLayout_2.setMargin(0)
        self.verticalLayout_2.setObjectName(_fromUtf8("verticalLayout_2"))

        self.retranslateUi(jssearchdlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), jssearchdlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), jssearchdlg.reject)
        QtCore.QMetaObject.connectSlotsByName(jssearchdlg)
        jssearchdlg.setTabOrder(self.searchstring, self.sforward)
        jssearchdlg.setTabOrder(self.sforward, self.sbackward)
        jssearchdlg.setTabOrder(self.sbackward, self.wrapround)
        jssearchdlg.setTabOrder(self.wrapround, self.igncase)
        jssearchdlg.setTabOrder(self.igncase, self.buttonBox)

    def retranslateUi(self, jssearchdlg):
        jssearchdlg.setWindowTitle(QtGui.QApplication.translate("jssearchdlg", "Search job strings", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox.setTitle(QtGui.QApplication.translate("jssearchdlg", "Direction", None, QtGui.QApplication.UnicodeUTF8))
        self.sforward.setToolTip(QtGui.QApplication.translate("jssearchdlg", "Select to search forwards", None, QtGui.QApplication.UnicodeUTF8))
        self.sforward.setText(QtGui.QApplication.translate("jssearchdlg", "Forwards", None, QtGui.QApplication.UnicodeUTF8))
        self.sbackward.setToolTip(QtGui.QApplication.translate("jssearchdlg", "Select to search backwards", None, QtGui.QApplication.UnicodeUTF8))
        self.sbackward.setText(QtGui.QApplication.translate("jssearchdlg", "Backwards", None, QtGui.QApplication.UnicodeUTF8))
        self.wrapround.setToolTip(QtGui.QApplication.translate("jssearchdlg", "Select to wrap search round", None, QtGui.QApplication.UnicodeUTF8))
        self.wrapround.setText(QtGui.QApplication.translate("jssearchdlg", "Wrap round", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("jssearchdlg", "Search for", None, QtGui.QApplication.UnicodeUTF8))
        self.searchstring.setToolTip(QtGui.QApplication.translate("jssearchdlg", "This is the string to search for with . for any character", None, QtGui.QApplication.UnicodeUTF8))
        self.igncase.setToolTip(QtGui.QApplication.translate("jssearchdlg", "Select this to ignore case differences on letters", None, QtGui.QApplication.UnicodeUTF8))
        self.igncase.setText(QtGui.QApplication.translate("jssearchdlg", "Ignore Case", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'vpermdlg.ui'
#
# Created: Sun Nov 25 19:49:47 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_vpermdlg(object):
    def setupUi(self, vpermdlg):
        vpermdlg.setObjectName(_fromUtf8("vpermdlg"))
        vpermdlg.resize(465, 458)
        self.buttonBox = QtGui.QDialogButtonBox(vpermdlg)
        self.buttonBox.setGeometry(QtCore.QRect(250, 400, 191, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.edvar = QtGui.QLabel(vpermdlg)
        self.edvar.setGeometry(QtCore.QRect(110, 30, 301, 17))
        self.edvar.setText(_fromUtf8(""))
        self.edvar.setObjectName(_fromUtf8("edvar"))
        self.label = QtGui.QLabel(vpermdlg)
        self.label.setGeometry(QtCore.QRect(10, 30, 101, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.layoutWidget = QtGui.QWidget(vpermdlg)
        self.layoutWidget.setGeometry(QtCore.QRect(60, 70, 313, 304))
        self.layoutWidget.setObjectName(_fromUtf8("layoutWidget"))
        self.gridLayout = QtGui.QGridLayout(self.layoutWidget)
        self.gridLayout.setMargin(0)
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.urdmd = QtGui.QCheckBox(self.layoutWidget)
        self.urdmd.setObjectName(_fromUtf8("urdmd"))
        self.gridLayout.addWidget(self.urdmd, 3, 1, 1, 1)
        self.gshow = QtGui.QCheckBox(self.layoutWidget)
        self.gshow.setObjectName(_fromUtf8("gshow"))
        self.gridLayout.addWidget(self.gshow, 2, 2, 1, 1)
        self.odel = QtGui.QCheckBox(self.layoutWidget)
        self.odel.setObjectName(_fromUtf8("odel"))
        self.gridLayout.addWidget(self.odel, 9, 3, 1, 1)
        self.gread = QtGui.QCheckBox(self.layoutWidget)
        self.gread.setObjectName(_fromUtf8("gread"))
        self.gridLayout.addWidget(self.gread, 0, 2, 1, 1)
        self.label_11 = QtGui.QLabel(self.layoutWidget)
        self.label_11.setObjectName(_fromUtf8("label_11"))
        self.gridLayout.addWidget(self.label_11, 9, 0, 1, 1)
        self.grdmd = QtGui.QCheckBox(self.layoutWidget)
        self.grdmd.setObjectName(_fromUtf8("grdmd"))
        self.gridLayout.addWidget(self.grdmd, 3, 2, 1, 1)
        self.label_8 = QtGui.QLabel(self.layoutWidget)
        self.label_8.setObjectName(_fromUtf8("label_8"))
        self.gridLayout.addWidget(self.label_8, 6, 0, 1, 1)
        self.ushow = QtGui.QCheckBox(self.layoutWidget)
        self.ushow.setObjectName(_fromUtf8("ushow"))
        self.gridLayout.addWidget(self.ushow, 2, 1, 1, 1)
        self.owrite = QtGui.QCheckBox(self.layoutWidget)
        self.owrite.setObjectName(_fromUtf8("owrite"))
        self.gridLayout.addWidget(self.owrite, 1, 3, 1, 1)
        self.label_5 = QtGui.QLabel(self.layoutWidget)
        self.label_5.setObjectName(_fromUtf8("label_5"))
        self.gridLayout.addWidget(self.label_5, 3, 0, 1, 1)
        self.uwrite = QtGui.QCheckBox(self.layoutWidget)
        self.uwrite.setObjectName(_fromUtf8("uwrite"))
        self.gridLayout.addWidget(self.uwrite, 1, 1, 1, 1)
        self.oggive = QtGui.QCheckBox(self.layoutWidget)
        self.oggive.setObjectName(_fromUtf8("oggive"))
        self.gridLayout.addWidget(self.oggive, 8, 3, 1, 1)
        self.ggtake = QtGui.QCheckBox(self.layoutWidget)
        self.ggtake.setObjectName(_fromUtf8("ggtake"))
        self.gridLayout.addWidget(self.ggtake, 6, 2, 1, 1)
        self.ogive = QtGui.QCheckBox(self.layoutWidget)
        self.ogive.setObjectName(_fromUtf8("ogive"))
        self.gridLayout.addWidget(self.ogive, 7, 3, 1, 1)
        self.label_3 = QtGui.QLabel(self.layoutWidget)
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.gridLayout.addWidget(self.label_3, 1, 0, 1, 1)
        self.gggive = QtGui.QCheckBox(self.layoutWidget)
        self.gggive.setObjectName(_fromUtf8("gggive"))
        self.gridLayout.addWidget(self.gggive, 8, 2, 1, 1)
        self.gtake = QtGui.QCheckBox(self.layoutWidget)
        self.gtake.setObjectName(_fromUtf8("gtake"))
        self.gridLayout.addWidget(self.gtake, 5, 2, 1, 1)
        self.gwrmd = QtGui.QCheckBox(self.layoutWidget)
        self.gwrmd.setObjectName(_fromUtf8("gwrmd"))
        self.gridLayout.addWidget(self.gwrmd, 4, 2, 1, 1)
        self.oshow = QtGui.QCheckBox(self.layoutWidget)
        self.oshow.setObjectName(_fromUtf8("oshow"))
        self.gridLayout.addWidget(self.oshow, 2, 3, 1, 1)
        self.label_4 = QtGui.QLabel(self.layoutWidget)
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.gridLayout.addWidget(self.label_4, 2, 0, 1, 1)
        self.ggive = QtGui.QCheckBox(self.layoutWidget)
        self.ggive.setObjectName(_fromUtf8("ggive"))
        self.gridLayout.addWidget(self.ggive, 7, 2, 1, 1)
        self.udel = QtGui.QCheckBox(self.layoutWidget)
        self.udel.setObjectName(_fromUtf8("udel"))
        self.gridLayout.addWidget(self.udel, 9, 1, 1, 1)
        self.label_9 = QtGui.QLabel(self.layoutWidget)
        self.label_9.setObjectName(_fromUtf8("label_9"))
        self.gridLayout.addWidget(self.label_9, 7, 0, 1, 1)
        self.ordmd = QtGui.QCheckBox(self.layoutWidget)
        self.ordmd.setObjectName(_fromUtf8("ordmd"))
        self.gridLayout.addWidget(self.ordmd, 3, 3, 1, 1)
        self.label_2 = QtGui.QLabel(self.layoutWidget)
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.gridLayout.addWidget(self.label_2, 0, 0, 1, 1)
        self.utake = QtGui.QCheckBox(self.layoutWidget)
        self.utake.setObjectName(_fromUtf8("utake"))
        self.gridLayout.addWidget(self.utake, 5, 1, 1, 1)
        self.label_10 = QtGui.QLabel(self.layoutWidget)
        self.label_10.setObjectName(_fromUtf8("label_10"))
        self.gridLayout.addWidget(self.label_10, 8, 0, 1, 1)
        self.ugtake = QtGui.QCheckBox(self.layoutWidget)
        self.ugtake.setObjectName(_fromUtf8("ugtake"))
        self.gridLayout.addWidget(self.ugtake, 6, 1, 1, 1)
        self.uread = QtGui.QCheckBox(self.layoutWidget)
        self.uread.setObjectName(_fromUtf8("uread"))
        self.gridLayout.addWidget(self.uread, 0, 1, 1, 1)
        self.uggive = QtGui.QCheckBox(self.layoutWidget)
        self.uggive.setObjectName(_fromUtf8("uggive"))
        self.gridLayout.addWidget(self.uggive, 8, 1, 1, 1)
        self.label_7 = QtGui.QLabel(self.layoutWidget)
        self.label_7.setObjectName(_fromUtf8("label_7"))
        self.gridLayout.addWidget(self.label_7, 5, 0, 1, 1)
        self.otake = QtGui.QCheckBox(self.layoutWidget)
        self.otake.setObjectName(_fromUtf8("otake"))
        self.gridLayout.addWidget(self.otake, 5, 3, 1, 1)
        self.ogtake = QtGui.QCheckBox(self.layoutWidget)
        self.ogtake.setObjectName(_fromUtf8("ogtake"))
        self.gridLayout.addWidget(self.ogtake, 6, 3, 1, 1)
        self.owrmd = QtGui.QCheckBox(self.layoutWidget)
        self.owrmd.setObjectName(_fromUtf8("owrmd"))
        self.gridLayout.addWidget(self.owrmd, 4, 3, 1, 1)
        self.gdel = QtGui.QCheckBox(self.layoutWidget)
        self.gdel.setObjectName(_fromUtf8("gdel"))
        self.gridLayout.addWidget(self.gdel, 9, 2, 1, 1)
        self.label_6 = QtGui.QLabel(self.layoutWidget)
        self.label_6.setObjectName(_fromUtf8("label_6"))
        self.gridLayout.addWidget(self.label_6, 4, 0, 1, 1)
        self.ugive = QtGui.QCheckBox(self.layoutWidget)
        self.ugive.setObjectName(_fromUtf8("ugive"))
        self.gridLayout.addWidget(self.ugive, 7, 1, 1, 1)
        self.oread = QtGui.QCheckBox(self.layoutWidget)
        self.oread.setObjectName(_fromUtf8("oread"))
        self.gridLayout.addWidget(self.oread, 0, 3, 1, 1)
        self.uwrmd = QtGui.QCheckBox(self.layoutWidget)
        self.uwrmd.setObjectName(_fromUtf8("uwrmd"))
        self.gridLayout.addWidget(self.uwrmd, 4, 1, 1, 1)
        self.gwrite = QtGui.QCheckBox(self.layoutWidget)
        self.gwrite.setObjectName(_fromUtf8("gwrite"))
        self.gridLayout.addWidget(self.gwrite, 1, 2, 1, 1)

        self.retranslateUi(vpermdlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), vpermdlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), vpermdlg.reject)
        QtCore.QMetaObject.connectSlotsByName(vpermdlg)
        vpermdlg.setTabOrder(self.uread, self.gread)
        vpermdlg.setTabOrder(self.gread, self.oread)
        vpermdlg.setTabOrder(self.oread, self.uwrite)
        vpermdlg.setTabOrder(self.uwrite, self.gwrite)
        vpermdlg.setTabOrder(self.gwrite, self.owrite)
        vpermdlg.setTabOrder(self.owrite, self.ushow)
        vpermdlg.setTabOrder(self.ushow, self.gshow)
        vpermdlg.setTabOrder(self.gshow, self.oshow)
        vpermdlg.setTabOrder(self.oshow, self.urdmd)
        vpermdlg.setTabOrder(self.urdmd, self.grdmd)
        vpermdlg.setTabOrder(self.grdmd, self.ordmd)
        vpermdlg.setTabOrder(self.ordmd, self.uwrmd)
        vpermdlg.setTabOrder(self.uwrmd, self.gwrmd)
        vpermdlg.setTabOrder(self.gwrmd, self.owrmd)
        vpermdlg.setTabOrder(self.owrmd, self.utake)
        vpermdlg.setTabOrder(self.utake, self.gtake)
        vpermdlg.setTabOrder(self.gtake, self.otake)
        vpermdlg.setTabOrder(self.otake, self.ugtake)
        vpermdlg.setTabOrder(self.ugtake, self.ggtake)
        vpermdlg.setTabOrder(self.ggtake, self.ogtake)
        vpermdlg.setTabOrder(self.ogtake, self.ugive)
        vpermdlg.setTabOrder(self.ugive, self.ggive)
        vpermdlg.setTabOrder(self.ggive, self.ogive)
        vpermdlg.setTabOrder(self.ogive, self.uggive)
        vpermdlg.setTabOrder(self.uggive, self.gggive)
        vpermdlg.setTabOrder(self.gggive, self.oggive)
        vpermdlg.setTabOrder(self.oggive, self.udel)
        vpermdlg.setTabOrder(self.udel, self.gdel)
        vpermdlg.setTabOrder(self.gdel, self.odel)
        vpermdlg.setTabOrder(self.odel, self.buttonBox)

    def retranslateUi(self, vpermdlg):
        vpermdlg.setWindowTitle(QtGui.QApplication.translate("vpermdlg", "Variable permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("vpermdlg", "Perms on var:", None, QtGui.QApplication.UnicodeUTF8))
        self.urdmd.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that the user can read the permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.urdmd.setText(QtGui.QApplication.translate("vpermdlg", "U", None, QtGui.QApplication.UnicodeUTF8))
        self.gshow.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that group  has reveal (is visible) permission", None, QtGui.QApplication.UnicodeUTF8))
        self.gshow.setText(QtGui.QApplication.translate("vpermdlg", "G", None, QtGui.QApplication.UnicodeUTF8))
        self.odel.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that others can delete the variable", None, QtGui.QApplication.UnicodeUTF8))
        self.odel.setText(QtGui.QApplication.translate("vpermdlg", "O", None, QtGui.QApplication.UnicodeUTF8))
        self.gread.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that group has read permission", None, QtGui.QApplication.UnicodeUTF8))
        self.gread.setText(QtGui.QApplication.translate("vpermdlg", "G", None, QtGui.QApplication.UnicodeUTF8))
        self.label_11.setText(QtGui.QApplication.translate("vpermdlg", "Delete", None, QtGui.QApplication.UnicodeUTF8))
        self.grdmd.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that the group can read the permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.grdmd.setText(QtGui.QApplication.translate("vpermdlg", "G", None, QtGui.QApplication.UnicodeUTF8))
        self.label_8.setText(QtGui.QApplication.translate("vpermdlg", "Assume group ownership", None, QtGui.QApplication.UnicodeUTF8))
        self.ushow.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that user has reveal (is visible) permission", None, QtGui.QApplication.UnicodeUTF8))
        self.ushow.setText(QtGui.QApplication.translate("vpermdlg", "U", None, QtGui.QApplication.UnicodeUTF8))
        self.owrite.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that others have write permission", None, QtGui.QApplication.UnicodeUTF8))
        self.owrite.setText(QtGui.QApplication.translate("vpermdlg", "O", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("vpermdlg", "Display mode", None, QtGui.QApplication.UnicodeUTF8))
        self.uwrite.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that user has write permission", None, QtGui.QApplication.UnicodeUTF8))
        self.uwrite.setText(QtGui.QApplication.translate("vpermdlg", "U", None, QtGui.QApplication.UnicodeUTF8))
        self.oggive.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that others can give away group ownership", None, QtGui.QApplication.UnicodeUTF8))
        self.oggive.setText(QtGui.QApplication.translate("vpermdlg", "O", None, QtGui.QApplication.UnicodeUTF8))
        self.ggtake.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that group can set the group", None, QtGui.QApplication.UnicodeUTF8))
        self.ggtake.setText(QtGui.QApplication.translate("vpermdlg", "G", None, QtGui.QApplication.UnicodeUTF8))
        self.ogive.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that others can give away ownership", None, QtGui.QApplication.UnicodeUTF8))
        self.ogive.setText(QtGui.QApplication.translate("vpermdlg", "O", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("vpermdlg", "Write", None, QtGui.QApplication.UnicodeUTF8))
        self.gggive.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that group can give away group ownership", None, QtGui.QApplication.UnicodeUTF8))
        self.gggive.setText(QtGui.QApplication.translate("vpermdlg", "G", None, QtGui.QApplication.UnicodeUTF8))
        self.gtake.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that group can set the owner", None, QtGui.QApplication.UnicodeUTF8))
        self.gtake.setText(QtGui.QApplication.translate("vpermdlg", "G", None, QtGui.QApplication.UnicodeUTF8))
        self.gwrmd.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that group can set permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.gwrmd.setText(QtGui.QApplication.translate("vpermdlg", "G", None, QtGui.QApplication.UnicodeUTF8))
        self.oshow.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that others have  reveal (is visible) permission", None, QtGui.QApplication.UnicodeUTF8))
        self.oshow.setText(QtGui.QApplication.translate("vpermdlg", "O", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("vpermdlg", "Reveal", None, QtGui.QApplication.UnicodeUTF8))
        self.ggive.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that group can give away ownership", None, QtGui.QApplication.UnicodeUTF8))
        self.ggive.setText(QtGui.QApplication.translate("vpermdlg", "G", None, QtGui.QApplication.UnicodeUTF8))
        self.udel.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that user can delete the variable", None, QtGui.QApplication.UnicodeUTF8))
        self.udel.setText(QtGui.QApplication.translate("vpermdlg", "U", None, QtGui.QApplication.UnicodeUTF8))
        self.label_9.setText(QtGui.QApplication.translate("vpermdlg", "Give away owner", None, QtGui.QApplication.UnicodeUTF8))
        self.ordmd.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that others can read the permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.ordmd.setText(QtGui.QApplication.translate("vpermdlg", "O", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("vpermdlg", "Read", None, QtGui.QApplication.UnicodeUTF8))
        self.utake.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that user can set the owner to him/herself", None, QtGui.QApplication.UnicodeUTF8))
        self.utake.setText(QtGui.QApplication.translate("vpermdlg", "U", None, QtGui.QApplication.UnicodeUTF8))
        self.label_10.setText(QtGui.QApplication.translate("vpermdlg", "Give away group", None, QtGui.QApplication.UnicodeUTF8))
        self.ugtake.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that user can set the group to his/her own", None, QtGui.QApplication.UnicodeUTF8))
        self.ugtake.setText(QtGui.QApplication.translate("vpermdlg", "U", None, QtGui.QApplication.UnicodeUTF8))
        self.uread.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that user has read permission", None, QtGui.QApplication.UnicodeUTF8))
        self.uread.setText(QtGui.QApplication.translate("vpermdlg", "U", None, QtGui.QApplication.UnicodeUTF8))
        self.uggive.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that user can give away the group ownership", None, QtGui.QApplication.UnicodeUTF8))
        self.uggive.setText(QtGui.QApplication.translate("vpermdlg", "U", None, QtGui.QApplication.UnicodeUTF8))
        self.label_7.setText(QtGui.QApplication.translate("vpermdlg", "Assume ownership", None, QtGui.QApplication.UnicodeUTF8))
        self.otake.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that others can set the owner", None, QtGui.QApplication.UnicodeUTF8))
        self.otake.setText(QtGui.QApplication.translate("vpermdlg", "O", None, QtGui.QApplication.UnicodeUTF8))
        self.ogtake.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that others can set the group", None, QtGui.QApplication.UnicodeUTF8))
        self.ogtake.setText(QtGui.QApplication.translate("vpermdlg", "O", None, QtGui.QApplication.UnicodeUTF8))
        self.owrmd.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that others can set permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.owrmd.setText(QtGui.QApplication.translate("vpermdlg", "O", None, QtGui.QApplication.UnicodeUTF8))
        self.gdel.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that group can delete the variable", None, QtGui.QApplication.UnicodeUTF8))
        self.gdel.setText(QtGui.QApplication.translate("vpermdlg", "G", None, QtGui.QApplication.UnicodeUTF8))
        self.label_6.setText(QtGui.QApplication.translate("vpermdlg", "Set mode", None, QtGui.QApplication.UnicodeUTF8))
        self.ugive.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that user can give the variable to a different owner", None, QtGui.QApplication.UnicodeUTF8))
        self.ugive.setText(QtGui.QApplication.translate("vpermdlg", "U", None, QtGui.QApplication.UnicodeUTF8))
        self.oread.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that others have read permission", None, QtGui.QApplication.UnicodeUTF8))
        self.oread.setText(QtGui.QApplication.translate("vpermdlg", "O", None, QtGui.QApplication.UnicodeUTF8))
        self.uwrmd.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that user can set permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.uwrmd.setText(QtGui.QApplication.translate("vpermdlg", "U", None, QtGui.QApplication.UnicodeUTF8))
        self.gwrite.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that group has write permission", None, QtGui.QApplication.UnicodeUTF8))
        self.gwrite.setText(QtGui.QApplication.translate("vpermdlg", "G", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'timelimdlg.ui'
#
# Created: Fri Nov 16 09:31:50 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_timelimdlg(object):
    def setupUi(self, timelimdlg):
        timelimdlg.setObjectName(_fromUtf8("timelimdlg"))
        timelimdlg.resize(511, 300)
        self.buttonBox = QtGui.QDialogButtonBox(timelimdlg)
        self.buttonBox.setGeometry(QtCore.QRect(260, 260, 201, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.edjob = QtGui.QLabel(timelimdlg)
        self.edjob.setGeometry(QtCore.QRect(110, 20, 331, 17))
        self.edjob.setText(_fromUtf8(""))
        self.edjob.setObjectName(_fromUtf8("edjob"))
        self.label = QtGui.QLabel(timelimdlg)
        self.label.setGeometry(QtCore.QRect(20, 20, 81, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.label_2 = QtGui.QLabel(timelimdlg)
        self.label_2.setGeometry(QtCore.QRect(20, 60, 91, 17))
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.deltime = QtGui.QSpinBox(timelimdlg)
        self.deltime.setGeometry(QtCore.QRect(140, 50, 91, 27))
        self.deltime.setMaximum(32767)
        self.deltime.setObjectName(_fromUtf8("deltime"))
        self.resetdel = QtGui.QPushButton(timelimdlg)
        self.resetdel.setGeometry(QtCore.QRect(270, 50, 98, 27))
        self.resetdel.setObjectName(_fromUtf8("resetdel"))
        self.label_3 = QtGui.QLabel(timelimdlg)
        self.label_3.setGeometry(QtCore.QRect(20, 100, 66, 17))
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.runth = QtGui.QSpinBox(timelimdlg)
        self.runth.setGeometry(QtCore.QRect(139, 90, 91, 27))
        self.runth.setMaximum(999)
        self.runth.setObjectName(_fromUtf8("runth"))
        self.runtm = QtGui.QSpinBox(timelimdlg)
        self.runtm.setGeometry(QtCore.QRect(240, 90, 71, 27))
        self.runtm.setMaximum(59)
        self.runtm.setObjectName(_fromUtf8("runtm"))
        self.runts = QtGui.QSpinBox(timelimdlg)
        self.runts.setGeometry(QtCore.QRect(320, 90, 71, 27))
        self.runts.setMaximum(59)
        self.runts.setObjectName(_fromUtf8("runts"))
        self.resetrunt = QtGui.QPushButton(timelimdlg)
        self.resetrunt.setGeometry(QtCore.QRect(410, 90, 71, 27))
        self.resetrunt.setObjectName(_fromUtf8("resetrunt"))
        self.label_4 = QtGui.QLabel(timelimdlg)
        self.label_4.setGeometry(QtCore.QRect(20, 140, 66, 17))
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.termsig = QtGui.QComboBox(timelimdlg)
        self.termsig.setGeometry(QtCore.QRect(140, 130, 171, 27))
        self.termsig.setObjectName(_fromUtf8("termsig"))
        self.label_5 = QtGui.QLabel(timelimdlg)
        self.label_5.setGeometry(QtCore.QRect(20, 180, 66, 17))
        self.label_5.setObjectName(_fromUtf8("label_5"))
        self.gtmin = QtGui.QSpinBox(timelimdlg)
        self.gtmin.setGeometry(QtCore.QRect(140, 180, 71, 27))
        self.gtmin.setMaximum(500)
        self.gtmin.setObjectName(_fromUtf8("gtmin"))
        self.gtsec = QtGui.QSpinBox(timelimdlg)
        self.gtsec.setGeometry(QtCore.QRect(240, 180, 60, 27))
        self.gtsec.setMaximum(59)
        self.gtsec.setObjectName(_fromUtf8("gtsec"))
        self.resetaddt = QtGui.QPushButton(timelimdlg)
        self.resetaddt.setGeometry(QtCore.QRect(340, 180, 71, 27))
        self.resetaddt.setObjectName(_fromUtf8("resetaddt"))

        self.retranslateUi(timelimdlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), timelimdlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), timelimdlg.reject)
        QtCore.QMetaObject.connectSlotsByName(timelimdlg)
        timelimdlg.setTabOrder(self.deltime, self.resetdel)
        timelimdlg.setTabOrder(self.resetdel, self.runth)
        timelimdlg.setTabOrder(self.runth, self.runtm)
        timelimdlg.setTabOrder(self.runtm, self.runts)
        timelimdlg.setTabOrder(self.runts, self.resetrunt)
        timelimdlg.setTabOrder(self.resetrunt, self.termsig)
        timelimdlg.setTabOrder(self.termsig, self.gtmin)
        timelimdlg.setTabOrder(self.gtmin, self.gtsec)
        timelimdlg.setTabOrder(self.gtsec, self.resetaddt)
        timelimdlg.setTabOrder(self.resetaddt, self.buttonBox)

    def retranslateUi(self, timelimdlg):
        timelimdlg.setWindowTitle(QtGui.QApplication.translate("timelimdlg", "Time limits", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("timelimdlg", "Editing job:", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("timelimdlg", "Delete time", None, QtGui.QApplication.UnicodeUTF8))
        self.deltime.setToolTip(QtGui.QApplication.translate("timelimdlg", "This is the time in hours afer the first submission\n"
"after which the job will be automatically deleted.\n"
"\n"
"Set to zero to suppress automatic deletion.", None, QtGui.QApplication.UnicodeUTF8))
        self.deltime.setSuffix(QtGui.QApplication.translate("timelimdlg", " hrs", None, QtGui.QApplication.UnicodeUTF8))
        self.resetdel.setToolTip(QtGui.QApplication.translate("timelimdlg", "Reset the delete time quickly to zero", None, QtGui.QApplication.UnicodeUTF8))
        self.resetdel.setText(QtGui.QApplication.translate("timelimdlg", "Reset", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("timelimdlg", "Run time", None, QtGui.QApplication.UnicodeUTF8))
        self.runth.setToolTip(QtGui.QApplication.translate("timelimdlg", "Give maximum run time here in hours.\n"
"\n"
"Zero means no limit.", None, QtGui.QApplication.UnicodeUTF8))
        self.runth.setSuffix(QtGui.QApplication.translate("timelimdlg", " H", None, QtGui.QApplication.UnicodeUTF8))
        self.runtm.setToolTip(QtGui.QApplication.translate("timelimdlg", "Give maximum run time here in minutes.\n"
"\n"
"Zero means no limit.", None, QtGui.QApplication.UnicodeUTF8))
        self.runtm.setSuffix(QtGui.QApplication.translate("timelimdlg", " M", None, QtGui.QApplication.UnicodeUTF8))
        self.runts.setToolTip(QtGui.QApplication.translate("timelimdlg", "Give maximum run time here in seconds.\n"
"\n"
"Zero means no limit.", None, QtGui.QApplication.UnicodeUTF8))
        self.runts.setSuffix(QtGui.QApplication.translate("timelimdlg", " S", None, QtGui.QApplication.UnicodeUTF8))
        self.resetrunt.setToolTip(QtGui.QApplication.translate("timelimdlg", "Reset run time limit to zero (cancelling it)", None, QtGui.QApplication.UnicodeUTF8))
        self.resetrunt.setText(QtGui.QApplication.translate("timelimdlg", "Reset", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("timelimdlg", "Signal", None, QtGui.QApplication.UnicodeUTF8))
        self.termsig.setToolTip(QtGui.QApplication.translate("timelimdlg", "This specifies the signal to be used after the run time is exhausted.\n"
"\n"
"Unless this is Kill then the job may continue for the Grace Time until\n"
"that is exhausted.", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("timelimdlg", "Add time", None, QtGui.QApplication.UnicodeUTF8))
        self.gtmin.setToolTip(QtGui.QApplication.translate("timelimdlg", "Additional time in minutes after first kill", None, QtGui.QApplication.UnicodeUTF8))
        self.gtmin.setSuffix(QtGui.QApplication.translate("timelimdlg", " M", None, QtGui.QApplication.UnicodeUTF8))
        self.gtsec.setToolTip(QtGui.QApplication.translate("timelimdlg", "Additional time in seconds after first kill", None, QtGui.QApplication.UnicodeUTF8))
        self.gtsec.setSuffix(QtGui.QApplication.translate("timelimdlg", " S", None, QtGui.QApplication.UnicodeUTF8))
        self.resetaddt.setToolTip(QtGui.QApplication.translate("timelimdlg", "Reset additional time limit to zero", None, QtGui.QApplication.UnicodeUTF8))
        self.resetaddt.setText(QtGui.QApplication.translate("timelimdlg", "Reset", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'jvsearchdlg.ui'
#
# Created: Tue Aug 14 11:40:54 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_jvsearchdlg(object):
    def setupUi(self, jvsearchdlg):
        jvsearchdlg.setObjectName(_fromUtf8("jvsearchdlg"))
        jvsearchdlg.resize(519, 246)
        self.buttonBox = QtGui.QDialogButtonBox(jvsearchdlg)
        self.buttonBox.setGeometry(QtCore.QRect(420, 20, 81, 91))
        self.buttonBox.setOrientation(QtCore.Qt.Vertical)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.searchstring = QtGui.QLineEdit(jvsearchdlg)
        self.searchstring.setGeometry(QtCore.QRect(130, 30, 251, 26))
        self.searchstring.setObjectName(_fromUtf8("searchstring"))
        self.label = QtGui.QLabel(jvsearchdlg)
        self.label.setGeometry(QtCore.QRect(30, 30, 81, 18))
        self.label.setObjectName(_fromUtf8("label"))
        self.groupBox = QtGui.QGroupBox(jvsearchdlg)
        self.groupBox.setGeometry(QtCore.QRect(40, 70, 120, 80))
        self.groupBox.setObjectName(_fromUtf8("groupBox"))
        self.sforward = QtGui.QRadioButton(self.groupBox)
        self.sforward.setGeometry(QtCore.QRect(10, 30, 108, 23))
        self.sforward.setChecked(True)
        self.sforward.setObjectName(_fromUtf8("sforward"))
        self.sbackward = QtGui.QRadioButton(self.groupBox)
        self.sbackward.setGeometry(QtCore.QRect(10, 60, 108, 21))
        self.sbackward.setObjectName(_fromUtf8("sbackward"))
        self.wrapround = QtGui.QCheckBox(jvsearchdlg)
        self.wrapround.setGeometry(QtCore.QRect(50, 170, 111, 23))
        self.wrapround.setObjectName(_fromUtf8("wrapround"))
        self.igncase = QtGui.QCheckBox(jvsearchdlg)
        self.igncase.setGeometry(QtCore.QRect(50, 200, 121, 23))
        self.igncase.setChecked(True)
        self.igncase.setObjectName(_fromUtf8("igncase"))
        self.splitter = QtGui.QSplitter(jvsearchdlg)
        self.splitter.setGeometry(QtCore.QRect(240, 80, 94, 139))
        self.splitter.setOrientation(QtCore.Qt.Vertical)
        self.splitter.setObjectName(_fromUtf8("splitter"))
        self.suser = QtGui.QCheckBox(self.splitter)
        self.suser.setObjectName(_fromUtf8("suser"))
        self.stitle = QtGui.QCheckBox(self.splitter)
        self.stitle.setObjectName(_fromUtf8("stitle"))
        self.sname = QtGui.QCheckBox(self.splitter)
        self.sname.setObjectName(_fromUtf8("sname"))
        self.scomment = QtGui.QCheckBox(self.splitter)
        self.scomment.setObjectName(_fromUtf8("scomment"))
        self.svalue = QtGui.QCheckBox(self.splitter)
        self.svalue.setObjectName(_fromUtf8("svalue"))

        self.retranslateUi(jvsearchdlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), jvsearchdlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), jvsearchdlg.reject)
        QtCore.QMetaObject.connectSlotsByName(jvsearchdlg)
        jvsearchdlg.setTabOrder(self.searchstring, self.sforward)
        jvsearchdlg.setTabOrder(self.sforward, self.sbackward)
        jvsearchdlg.setTabOrder(self.sbackward, self.wrapround)
        jvsearchdlg.setTabOrder(self.wrapround, self.igncase)
        jvsearchdlg.setTabOrder(self.igncase, self.suser)
        jvsearchdlg.setTabOrder(self.suser, self.stitle)
        jvsearchdlg.setTabOrder(self.stitle, self.sname)
        jvsearchdlg.setTabOrder(self.sname, self.scomment)
        jvsearchdlg.setTabOrder(self.scomment, self.svalue)
        jvsearchdlg.setTabOrder(self.svalue, self.buttonBox)

    def retranslateUi(self, jvsearchdlg):
        jvsearchdlg.setWindowTitle(QtGui.QApplication.translate("jvsearchdlg", "Search for job/variable", None, QtGui.QApplication.UnicodeUTF8))
        self.searchstring.setToolTip(QtGui.QApplication.translate("jvsearchdlg", "This is the string to search for with . for any character", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("jvsearchdlg", "Search for", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox.setTitle(QtGui.QApplication.translate("jvsearchdlg", "Direction", None, QtGui.QApplication.UnicodeUTF8))
        self.sforward.setToolTip(QtGui.QApplication.translate("jvsearchdlg", "Select to search forwards", None, QtGui.QApplication.UnicodeUTF8))
        self.sforward.setText(QtGui.QApplication.translate("jvsearchdlg", "Forwards", None, QtGui.QApplication.UnicodeUTF8))
        self.sbackward.setToolTip(QtGui.QApplication.translate("jvsearchdlg", "Select to search backwards", None, QtGui.QApplication.UnicodeUTF8))
        self.sbackward.setText(QtGui.QApplication.translate("jvsearchdlg", "Backwards", None, QtGui.QApplication.UnicodeUTF8))
        self.wrapround.setToolTip(QtGui.QApplication.translate("jvsearchdlg", "Select to wrap search round", None, QtGui.QApplication.UnicodeUTF8))
        self.wrapround.setText(QtGui.QApplication.translate("jvsearchdlg", "Wrap round", None, QtGui.QApplication.UnicodeUTF8))
        self.igncase.setToolTip(QtGui.QApplication.translate("jvsearchdlg", "Select this to ignore case differences on letters", None, QtGui.QApplication.UnicodeUTF8))
        self.igncase.setText(QtGui.QApplication.translate("jvsearchdlg", "Ignore Case", None, QtGui.QApplication.UnicodeUTF8))
        self.suser.setToolTip(QtGui.QApplication.translate("jvsearchdlg", "Select to search for user owning job or variable", None, QtGui.QApplication.UnicodeUTF8))
        self.suser.setText(QtGui.QApplication.translate("jvsearchdlg", "User", None, QtGui.QApplication.UnicodeUTF8))
        self.stitle.setToolTip(QtGui.QApplication.translate("jvsearchdlg", "Select to search by job title", None, QtGui.QApplication.UnicodeUTF8))
        self.stitle.setText(QtGui.QApplication.translate("jvsearchdlg", "Title", None, QtGui.QApplication.UnicodeUTF8))
        self.sname.setToolTip(QtGui.QApplication.translate("jvsearchdlg", "Select to search by variable name", None, QtGui.QApplication.UnicodeUTF8))
        self.sname.setText(QtGui.QApplication.translate("jvsearchdlg", "Name", None, QtGui.QApplication.UnicodeUTF8))
        self.scomment.setToolTip(QtGui.QApplication.translate("jvsearchdlg", "Select to search by variable comment", None, QtGui.QApplication.UnicodeUTF8))
        self.scomment.setText(QtGui.QApplication.translate("jvsearchdlg", "Comment", None, QtGui.QApplication.UnicodeUTF8))
        self.svalue.setToolTip(QtGui.QApplication.translate("jvsearchdlg", "Select to search by value of variable", None, QtGui.QApplication.UnicodeUTF8))
        self.svalue.setText(QtGui.QApplication.translate("jvsearchdlg", "Value", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'winoptsdlg.ui'
#
# Created: Tue Aug 14 11:40:54 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_winoptdlg(object):
    def setupUi(self, winoptdlg):
        winoptdlg.setObjectName(_fromUtf8("winoptdlg"))
        winoptdlg.resize(602, 324)
        self.removeall = QtGui.QPushButton(winoptdlg)
        self.removeall.setGeometry(QtCore.QRect(190, 260, 181, 31))
        self.removeall.setObjectName(_fromUtf8("removeall"))
        self.buttonBox = QtGui.QDialogButtonBox(winoptdlg)
        self.buttonBox.setGeometry(QtCore.QRect(500, 60, 81, 241))
        self.buttonBox.setOrientation(QtCore.Qt.Vertical)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.label_4 = QtGui.QLabel(winoptdlg)
        self.label_4.setGeometry(QtCore.QRect(200, 20, 221, 17))
        font = QtGui.QFont()
        font.setUnderline(True)
        self.label_4.setFont(font)
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.label = QtGui.QLabel(winoptdlg)
        self.label.setGeometry(QtCore.QRect(60, 70, 91, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.queuename = QtGui.QComboBox(winoptdlg)
        self.queuename.setGeometry(QtCore.QRect(180, 60, 231, 27))
        self.queuename.setEditable(True)
        self.queuename.setObjectName(_fromUtf8("queuename"))
        self.inclnull = QtGui.QCheckBox(winoptdlg)
        self.inclnull.setGeometry(QtCore.QRect(50, 110, 411, 22))
        self.inclnull.setChecked(True)
        self.inclnull.setObjectName(_fromUtf8("inclnull"))
        self.label_2 = QtGui.QLabel(winoptdlg)
        self.label_2.setGeometry(QtCore.QRect(60, 160, 111, 17))
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.label_3 = QtGui.QLabel(winoptdlg)
        self.label_3.setGeometry(QtCore.QRect(60, 210, 101, 17))
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.username = QtGui.QComboBox(winoptdlg)
        self.username.setGeometry(QtCore.QRect(180, 150, 231, 27))
        self.username.setEditable(True)
        self.username.setObjectName(_fromUtf8("username"))
        self.groupname = QtGui.QComboBox(winoptdlg)
        self.groupname.setGeometry(QtCore.QRect(180, 210, 231, 27))
        self.groupname.setEditable(True)
        self.groupname.setObjectName(_fromUtf8("groupname"))

        self.retranslateUi(winoptdlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), winoptdlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), winoptdlg.reject)
        QtCore.QMetaObject.connectSlotsByName(winoptdlg)
        winoptdlg.setTabOrder(self.queuename, self.inclnull)
        winoptdlg.setTabOrder(self.inclnull, self.username)
        winoptdlg.setTabOrder(self.username, self.groupname)
        winoptdlg.setTabOrder(self.groupname, self.removeall)
        winoptdlg.setTabOrder(self.removeall, self.buttonBox)

    def retranslateUi(self, winoptdlg):
        winoptdlg.setWindowTitle(QtGui.QApplication.translate("winoptdlg", "Window Options", None, QtGui.QApplication.UnicodeUTF8))
        self.removeall.setToolTip(QtGui.QApplication.translate("winoptdlg", "Clear all limits on view restrictions", None, QtGui.QApplication.UnicodeUTF8))
        self.removeall.setText(QtGui.QApplication.translate("winoptdlg", "Remove all restrictions", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("winoptdlg", "These are for the current window", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("winoptdlg", "Job queue", None, QtGui.QApplication.UnicodeUTF8))
        self.queuename.setToolTip(QtGui.QApplication.translate("winoptdlg", "Select a queue name to restrict the view to using the button.\n"
"You can also select lists of queue names using commas and \"shell glob\" like\n"
"matching - e.g. q*,*list", None, QtGui.QApplication.UnicodeUTF8))
        self.inclnull.setToolTip(QtGui.QApplication.translate("winoptdlg", "Select this to include jobs with no queue name at all\n"
"when you are limiting the display to a queue name\n"
"or names.", None, QtGui.QApplication.UnicodeUTF8))
        self.inclnull.setText(QtGui.QApplication.translate("winoptdlg", "Include jobs with no queue prefix when limiting by queue", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("winoptdlg", "User name(s)", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("winoptdlg", "Group Name(s)", None, QtGui.QApplication.UnicodeUTF8))
        self.username.setToolTip(QtGui.QApplication.translate("winoptdlg", "Select a user name to restrict the view to using the button.\n"
"You can also select lists of user names using commas and \"shell glob\" like\n"
"matching - e.g. j*,*smith", None, QtGui.QApplication.UnicodeUTF8))
        self.groupname.setToolTip(QtGui.QApplication.translate("winoptdlg", "Select a group name to restrict the view to using the button.\n"
"You can also select lists of group names using commas and \"shell glob\" like\n"
"matching - e.g. q*,*list", None, QtGui.QApplication.UnicodeUTF8))

